@@ -26,6 +26,7 @@
 #include "vtkShortArray.h"
 #include "vtkSignedCharArray.h"
 #include "vtkStringArray.h"
+#include "vtkUnicodeStringArray.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnsignedIntArray.h"
 #include "vtkUnsignedLongArray.h"
@@ -44,11 +45,7 @@
 # endif
 #endif
 
-vtkCxxRevisionMacro(vtkAbstractArray, "$Revision: 1.15 $");
-
-//----------------------------------------------------------------------------
-// vtkAbstractArray::SetInformation(vtkInformation *info)
-vtkCxxSetObjectMacro(vtkAbstractArray,Information,vtkInformation);
+vtkCxxRevisionMacro(vtkAbstractArray, "$Revision: 1.17 $");
 
 //----------------------------------------------------------------------------
 // Construct object with sane defaults.
@@ -68,6 +65,25 @@ vtkAbstractArray::~vtkAbstractArray()
   this->SetInformation(NULL);
 }
 
+//----------------------------------------------------------------------------
+void vtkAbstractArray::SetInformation(vtkInformation *args)
+{
+  // Same as in vtkCxxSetObjectMacro, but no Modified() so that
+  // this doesn't cause extra pipeline updates.
+  vtkDebugMacro(<< this->GetClassName() << " (" << this
+      << "): setting Information to " << args );
+  if (this->Information != args)
+    {
+    vtkInformation* tempSGMacroVar = this->Information;
+    this->Information = args;
+    if (this->Information != NULL) { this->Information->Register(this); }
+    if (tempSGMacroVar != NULL)
+      {
+      tempSGMacroVar->UnRegister(this);
+      }
+    }
+}
+
 //----------------------------------------------------------------------------
 void vtkAbstractArray::GetTuples(vtkIdList* ptIds, vtkAbstractArray* aa)
 {
@@ -161,6 +177,10 @@ int vtkAbstractArray::GetDataTypeSize(int type)
       return 0;
       break;
 
+    case VTK_UNICODE_STRING:
+      return 0;
+      break;
+
     default:
       vtkGenericWarningMacro(<<"Unsupported data type!");
     }
@@ -235,6 +255,9 @@ vtkAbstractArray* vtkAbstractArray::CreateArray(int dataType)
     case VTK_STRING:
       return vtkStringArray::New();
 
+    case VTK_UNICODE_STRING:
+      return vtkUnicodeStringArray::New();
+
     case VTK_VARIANT:
       return vtkVariantArray::New();
 
