@@ -33,6 +33,7 @@
 #include "vtkSystemIncludes.h" // To define ostream
 #include "vtkSetGet.h"         // For vtkNotUsed macro
 #include "vtkStdString.h"
+#include "vtkUnicodeString.h"
 
 //
 // The following should be eventually placed in vtkSetGet.h
@@ -49,10 +50,15 @@
   vtkArrayIteratorTemplateMacroCase(VTK_VARIANT, vtkVariant, call);
 
 class vtkStdString;
+class vtkUnicodeString;
 class vtkObjectBase;
 class vtkAbstractArray;
+class vtkVariant;
 struct vtkVariantLessThan;
 
+VTK_COMMON_EXPORT ostream& operator << ( ostream& os, const vtkVariant& val );
+
+
 class VTK_COMMON_EXPORT vtkVariant
 {
 public:
@@ -69,6 +75,10 @@ public:
   // Copy constructor.
   vtkVariant(const vtkVariant & other);
 
+  // Description:
+  // Create a bool variant. Internally store it as char.
+  vtkVariant(bool value);
+
   // Description:
   // Create a char variant.
   vtkVariant(char value);
@@ -140,6 +150,10 @@ public:
   // Create a string variant from a std string.
   vtkVariant(vtkStdString value);
 
+  // Description:
+  // Create a Unicode string variant
+  vtkVariant(const vtkUnicodeString& value);
+
   // Description:
   // Create a vtkObjectBase variant.
   vtkVariant(vtkObjectBase* value);
@@ -156,6 +170,10 @@ public:
   // Get whether the variant is a string.
   bool IsString() const;
 
+  // Description:
+  // Get whether the variant is a Unicode string.
+  bool IsUnicodeString() const;
+
   // Description:
   // Get whether the variant is any numeric type.
   bool IsNumeric() const;
@@ -240,6 +258,10 @@ public:
   // Convert the variant to a string.
   vtkStdString ToString() const;
 
+  // Description:
+  // convert the variant to a Unicode string.
+  vtkUnicodeString ToUnicodeString() const;
+
   // Description:
   // Convert the variant to a numeric type:
   // If it holds a numeric, cast to the appropriate type.
@@ -328,13 +350,14 @@ public:
   bool operator<=(const vtkVariant &other) const;
   bool operator>=(const vtkVariant &other) const;
 
-
+  friend VTK_COMMON_EXPORT ostream& operator << ( ostream& os, const vtkVariant& val );
 
 
 private:
   union
   {
     vtkStdString* String;
+    vtkUnicodeString* UnicodeString;
     float Float;
     double Double;
     char Char;
