@@ -186,6 +186,20 @@ public:
   // built before attempting to access buckets (octants).
   virtual int GetNumberOfBuckets(void);
 
+  // Description:
+  // Returns the Id of the cell containing the point, 
+  // returns -1 if no cell found. This interface uses a tolerance of zero
+  virtual vtkIdType FindCell(double x[3])
+    { return this->Superclass::FindCell(x); }
+
+  // Description:
+  // Find the cell containing a given point. returns -1 if no cell found
+  // the cell parameters are copied into the supplied variables, a cell must
+  // be provided to store the information.
+  virtual vtkIdType FindCell(
+    double x[3], double tol2, vtkGenericCell *GenCell, 
+    double pcoords[3], double *weights);
+
   // Description:
   // Return a list of unique cell ids inside of a given bounding box. The
   // user must provide the vtkIdList to populate. This method returns data
@@ -205,6 +219,9 @@ public:
   // Satisfy vtkLocator abstract interface.
   virtual void FreeSearchStructure();
   virtual void BuildLocator();
+  virtual void BuildLocatorIfNeeded();
+  virtual void ForceBuildLocator();
+  virtual void BuildLocatorInternal();
   virtual void GenerateRepresentation(int level, vtkPolyData *pd);
   
 protected:
