@@ -15,7 +15,7 @@
 #include "vtkCellTypes.h"
 #include "vtkObjectFactory.h"  
 
-vtkCxxRevisionMacro(vtkCellTypes, "$Revision: 1.4 $");
+vtkCxxRevisionMacro(vtkCellTypes, "$Revision: 1.5 $");
 vtkStandardNewMacro(vtkCellTypes);
 
 // This list should contain the cell class names in
@@ -56,8 +56,8 @@ static const char* vtkCellTypesStrings[] = {
   "vtkQuadraticLinearWedge",
   "vtkBiquadraticQuadraticWedge",
   "vtkBiquadraticQuadraticHexahedron",
-  "UnknownClass",
-  "UnknownClass",
+  "vtkBiQuadraticTriangle",
+  "vtkCubicLine",
   "UnknownClass",
   "UnknownClass",
   "UnknownClass",
