@@ -79,7 +79,7 @@ public:
   // Satisfy the vtkCell API. This method contours by triangulating the
   // cell and then contouring the resulting tetrahedra.
   virtual void Contour(double value, vtkDataArray *cellScalars,
-                       vtkPointLocator *locator, vtkCellArray *verts,
+                       vtkIncrementalPointLocator *locator, vtkCellArray *verts,
                        vtkCellArray *lines, vtkCellArray *polys,
                        vtkPointData *inPd, vtkPointData *outPd,
                        vtkCellData *inCd, vtkIdType cellId, vtkCellData *outCd);
@@ -89,7 +89,7 @@ public:
   // cell and then adding clip-edge intersection points into the
   // triangulation; extracting the clipped region.
   virtual void Clip(double value, vtkDataArray *cellScalars,
-                    vtkPointLocator *locator, vtkCellArray *connectivity,
+                    vtkIncrementalPointLocator *locator, vtkCellArray *connectivity,
                     vtkPointData *inPd, vtkPointData *outPd,
                     vtkCellData *inCd, vtkIdType cellId, vtkCellData *outCd,
                     int insideOut);
