@@ -28,7 +28,7 @@
 
 #include <math.h>
 
-vtkCxxRevisionMacro(vtkDataSet, "$Revision: 1.14 $");
+vtkCxxRevisionMacro(vtkDataSet, "$Revision: 1.15 $");
 
 //----------------------------------------------------------------------------
 // Constructor with default bounds (0,1, 0,1, 0,1).
@@ -652,6 +652,36 @@ vtkDataSet* vtkDataSet::GetData(vtkInformationVector* v, int i)
   return vtkDataSet::GetData(v->GetInformationObject(i));
 }
 
+//----------------------------------------------------------------------------
+vtkFieldData* vtkDataSet::GetAttributesAsFieldData(int type)
+{
+  switch(type)
+    {
+    case POINT:
+      return this->GetPointData();
+      break;
+    case CELL:
+      return this->GetCellData();
+      break;
+    }
+  return this->Superclass::GetAttributesAsFieldData(type);
+}
+
+//----------------------------------------------------------------------------
+vtkIdType vtkDataSet::GetNumberOfElements(int type)
+{
+  switch (type)
+    {
+    case POINT:
+      return this->GetNumberOfPoints();
+      break;
+    case CELL:
+      return this->GetNumberOfCells();
+      break;
+    }
+  return this->Superclass::GetNumberOfElements(type);;
+}
+
 //----------------------------------------------------------------------------
 void vtkDataSet::PrintSelf(ostream& os, vtkIndent indent)
 {
