@@ -26,7 +26,7 @@
 
 #include <math.h>
 
-vtkCxxRevisionMacro(vtkImageToStructuredPoints, "$Revision: 1.64 $");
+vtkCxxRevisionMacro(vtkImageToStructuredPoints, "$Revision: 1.65 $");
 vtkStandardNewMacro(vtkImageToStructuredPoints);
 
 //----------------------------------------------------------------------------
@@ -48,6 +48,12 @@ void vtkImageToStructuredPoints::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os,indent);
 }
 
+//----------------------------------------------------------------------------
+vtkStructuredPoints* vtkImageToStructuredPoints::GetStructuredPointsOutput()
+{
+  return vtkStructuredPoints::SafeDownCast(this->GetOutputDataObject(0));
+}
+
 //----------------------------------------------------------------------------
 void vtkImageToStructuredPoints::SetVectorInput(vtkImageData *input)
 {
