@@ -29,7 +29,7 @@
 //----------------------------------------------------------------------------
 // class vtkMutableUndirectedGraph
 //----------------------------------------------------------------------------
-vtkCxxRevisionMacro(vtkMutableUndirectedGraph, "$Revision: 1.5 $");
+vtkCxxRevisionMacro(vtkMutableUndirectedGraph, "$Revision: 1.6 $");
 vtkStandardNewMacro(vtkMutableUndirectedGraph);
 //----------------------------------------------------------------------------
 vtkMutableUndirectedGraph::vtkMutableUndirectedGraph()
@@ -207,6 +207,30 @@ vtkGraphEdge *vtkMutableUndirectedGraph::AddGraphEdge(vtkIdType u, vtkIdType v)
   return this->GraphEdge;
 }
 
+//----------------------------------------------------------------------------
+void vtkMutableUndirectedGraph::RemoveVertex(vtkIdType v)
+{
+  this->RemoveVertexInternal(v, false);
+}
+
+//----------------------------------------------------------------------------
+void vtkMutableUndirectedGraph::RemoveEdge(vtkIdType e)
+{
+  this->RemoveEdgeInternal(e, false);
+}
+
+//----------------------------------------------------------------------------
+void vtkMutableUndirectedGraph::RemoveVertices(vtkIdTypeArray* arr)
+{
+  this->RemoveVerticesInternal(arr, false);
+}
+
+//----------------------------------------------------------------------------
+void vtkMutableUndirectedGraph::RemoveEdges(vtkIdTypeArray* arr)
+{
+  this->RemoveEdgesInternal(arr, false);
+}
+
 //----------------------------------------------------------------------------
 void vtkMutableUndirectedGraph::PrintSelf(ostream& os, vtkIndent indent)
 {
