@@ -27,8 +27,10 @@
 #include "vtkTriangle.h"
 #include "vtkBox.h"
 #include "vtkMergePoints.h"
+#include "vtkIncrementalPointLocator.h"
+#include "vtkSmartPointer.h"
 
-vtkCxxRevisionMacro(vtkPolygon, "$Revision: 1.8.2.1 $");
+vtkCxxRevisionMacro(vtkPolygon, "$Revision: 1.12 $");
 vtkStandardNewMacro(vtkPolygon);
 
 //----------------------------------------------------------------------------
@@ -57,6 +59,18 @@ vtkPolygon::~vtkPolygon()
   this->Line->Delete();
 }
 
+//----------------------------------------------------------------------------
+double vtkPolygon::ComputeArea()
+{
+  double normal[3]; //not used, but required for the 
+                    //following ComputeArea call
+  return vtkPolygon::ComputeArea(this->GetPoints(), 
+                                 this->GetNumberOfPoints(), 
+                                 this->GetPointIds()->GetPointer(0), 
+                                 normal);
+
+}
+
 #define VTK_POLYGON_FAILURE -1
 #define VTK_POLYGON_OUTSIDE 0
 #define VTK_POLYGON_INSIDE 1
@@ -1237,7 +1251,7 @@ int vtkPolygon::CellBoundary(int vtkNotUsed(subId), double pcoords[3],
 
 //----------------------------------------------------------------------------
 void vtkPolygon::Contour(double value, vtkDataArray *cellScalars, 
-                         vtkPointLocator *locator,
+                         vtkIncrementalPointLocator *locator,
                          vtkCellArray *verts, vtkCellArray *lines, 
                          vtkCellArray *polys,
                          vtkPointData *inPd, vtkPointData *outPd,
@@ -1493,7 +1507,7 @@ void vtkPolygon::Derivatives(int vtkNotUsed(subId), double pcoords[3],
 
 //----------------------------------------------------------------------------
 void vtkPolygon::Clip(double value, vtkDataArray *cellScalars,
-                      vtkPointLocator *locator, vtkCellArray *tris,
+                      vtkIncrementalPointLocator *locator, vtkCellArray *tris,
                       vtkPointData *inPD, vtkPointData *outPD,
                       vtkCellData *inCD, vtkIdType cellId, vtkCellData *outCD,
                       int insideOut)
