@@ -34,6 +34,7 @@ class vtkLine;
 class vtkQuad;
 class vtkTriangle;
 class vtkUnstructuredGrid;
+class vtkIncrementalPointLocator;
 
 class VTK_FILTERING_EXPORT vtkPyramid : public vtkCell3D
 {
@@ -57,7 +58,7 @@ public:
   vtkCell *GetFace(int faceId);
   int CellBoundary(int subId, double pcoords[3], vtkIdList *pts);
   void Contour(double value, vtkDataArray *cellScalars,
-               vtkPointLocator *locator, vtkCellArray *verts,
+               vtkIncrementalPointLocator *locator, vtkCellArray *verts,
                vtkCellArray *lines, vtkCellArray *polys,
                vtkPointData *inPd, vtkPointData *outPd,
                vtkCellData *inCd, vtkIdType cellId, vtkCellData *outCd);
