@@ -22,7 +22,7 @@
 #include "vtkDoubleArray.h"
 #include "vtkPoints.h"
 
-vtkCxxRevisionMacro(vtkQuadraticTetra, "$Revision: 1.11 $");
+vtkCxxRevisionMacro(vtkQuadraticTetra, "$Revision: 1.12 $");
 vtkStandardNewMacro(vtkQuadraticTetra);
 
 //----------------------------------------------------------------------------
@@ -280,7 +280,7 @@ int vtkQuadraticTetra::CellBoundary(int subId, double pcoords[3],
 
 //----------------------------------------------------------------------------
 void vtkQuadraticTetra::Contour(double value, vtkDataArray* cellScalars,
-                                vtkPointLocator* locator,
+                                vtkIncrementalPointLocator* locator,
                                 vtkCellArray *verts, vtkCellArray* lines,
                                 vtkCellArray* polys,
                                 vtkPointData* inPd, vtkPointData* outPd,
@@ -445,7 +445,7 @@ void vtkQuadraticTetra::Derivatives(int vtkNotUsed(subId),
 // Clip this quadratic tetra using the scalar value provided. Like contouring,
 // except that it cuts the tetra to produce other tetra.
 void vtkQuadraticTetra::Clip(double value, vtkDataArray* cellScalars,
-                             vtkPointLocator* locator, vtkCellArray* tetras,
+                             vtkIncrementalPointLocator* locator, vtkCellArray* tetras,
                              vtkPointData* inPd, vtkPointData* outPd,
                              vtkCellData* inCd, vtkIdType cellId,
                              vtkCellData* outCd, int insideOut)
