@@ -15,7 +15,6 @@
 #include "vtkRectilinearGrid.h"
 
 #include "vtkCellData.h"
-#include "vtkExtentTranslator.h"
 #include "vtkDoubleArray.h"
 #include "vtkGenericCell.h"
 #include "vtkInformation.h"
@@ -31,7 +30,7 @@
 #include "vtkVertex.h"
 #include "vtkVoxel.h"
 
-vtkCxxRevisionMacro(vtkRectilinearGrid, "$Revision: 1.9 $");
+vtkCxxRevisionMacro(vtkRectilinearGrid, "$Revision: 1.13 $");
 vtkStandardNewMacro(vtkRectilinearGrid);
 
 vtkCxxSetObjectMacro(vtkRectilinearGrid,XCoordinates,vtkDataArray);
@@ -49,13 +48,14 @@ vtkRectilinearGrid::vtkRectilinearGrid()
   this->Dimensions[0] = 0;
   this->Dimensions[1] = 0;
   this->Dimensions[2] = 0;
-  this->Information->Set(vtkDataObject::DATA_EXTENT_TYPE(), VTK_3D_EXTENT);
-  this->Information->Set(vtkDataObject::DATA_EXTENT(), this->Extent, 6);
 
   int extent[6] = {0, -1, 0, -1, 0, -1};
   memcpy(this->Extent, extent, 6*sizeof(int));
   this->DataDescription = VTK_EMPTY;
 
+  this->Information->Set(vtkDataObject::DATA_EXTENT_TYPE(), VTK_3D_EXTENT);
+  this->Information->Set(vtkDataObject::DATA_EXTENT(), this->Extent, 6);
+
   vtkDoubleArray *fs=vtkDoubleArray::New(); fs->Allocate(1);
   fs->SetNumberOfTuples(1);
   fs->SetComponent(0, 0, 0.0);
@@ -72,7 +72,8 @@ vtkRectilinearGrid::vtkRectilinearGrid()
 //----------------------------------------------------------------------------
 vtkRectilinearGrid::~vtkRectilinearGrid()
 {
-  this->Initialize();
+  this->Cleanup();
+
   this->Vertex->Delete();
   this->Line->Delete();
   this->Pixel->Delete();
@@ -81,14 +82,8 @@ vtkRectilinearGrid::~vtkRectilinearGrid()
 }
 
 //----------------------------------------------------------------------------
-void vtkRectilinearGrid::Initialize()
+void vtkRectilinearGrid::Cleanup()
 {
-  this->Superclass::Initialize();
-  if(this->Information)
-    {
-  this->SetDimensions(0,0,0);
-    }
-
   if ( this->XCoordinates ) 
     {
     this->XCoordinates->UnRegister(this);
@@ -108,6 +103,19 @@ void vtkRectilinearGrid::Initialize()
     }
 }
 
+//----------------------------------------------------------------------------
+void vtkRectilinearGrid::Initialize()
+{
+  this->Superclass::Initialize();
+
+  if(this->Information)
+    {
+    this->SetDimensions(0,0,0);
+    }
+
+  this->Cleanup();
+}
+
 //----------------------------------------------------------------------------
 // Copy the geometric and topological structure of an input rectilinear grid
 // object.
@@ -598,10 +606,9 @@ vtkIdType vtkRectilinearGrid::FindPoint(double x[3])
 //
 //  From this location get the point id
 //
-  return loc[2]*this->Dimensions[0]*this->Dimensions[1] +
-         loc[1]*this->Dimensions[0] + loc[0];
-  
+  return this->ComputePointId(loc);
 }
+
 vtkIdType vtkRectilinearGrid::FindCell(double x[3], vtkCell *vtkNotUsed(cell), 
                                        vtkGenericCell *vtkNotUsed(gencell),
                                        vtkIdType vtkNotUsed(cellId), 
@@ -633,8 +640,7 @@ vtkIdType vtkRectilinearGrid::FindCell(double x[3], vtkCell *vtkNotUsed(cell),
   //  From this location get the cell id
   //
   subId = 0;
-  return loc[2] * (this->Dimensions[0]-1)*(this->Dimensions[1]-1) +
-         loc[1] * (this->Dimensions[0]-1) + loc[0];
+  return this->ComputeCellId(loc);
 }
 
 //----------------------------------------------------------------------------
@@ -660,8 +666,7 @@ vtkCell *vtkRectilinearGrid::FindAndGetCell(double x[3],
   //
   // Get the cell
   //
-  cellId = loc[2] * (this->Dimensions[0]-1)*(this->Dimensions[1]-1) +
-           loc[1] * (this->Dimensions[0]-1) + loc[0];
+  cellId = this->ComputeCellId(loc);
 
   return vtkRectilinearGrid::GetCell(cellId);
 }
