@@ -93,6 +93,13 @@ public:
   // Return the MTime taking into account changes to the properties
   unsigned long GetMTime();
 
+  // Description:
+  // Dumps the contents of the selection, giving basic information only.
+  virtual void Dump();
+  //BTX
+  virtual void Dump(ostream& os);
+  //ETX
+
   // Description:
   // Retrieve a vtkSelection stored inside an invormation object.
   static vtkSelection* GetData(vtkInformation* info);
