@@ -16,7 +16,6 @@
 
 #include "vtkCellData.h"
 #include "vtkEmptyCell.h"
-#include "vtkExtentTranslator.h"
 #include "vtkGenericCell.h"
 #include "vtkHexahedron.h"
 #include "vtkInformation.h"
@@ -30,7 +29,7 @@
 #include "vtkQuad.h"
 #include "vtkVertex.h"
 
-vtkCxxRevisionMacro(vtkStructuredGrid, "$Revision: 1.5.6.1 $");
+vtkCxxRevisionMacro(vtkStructuredGrid, "$Revision: 1.11 $");
 vtkStandardNewMacro(vtkStructuredGrid);
 
 vtkCxxSetObjectMacro(vtkStructuredGrid,
@@ -61,17 +60,16 @@ vtkStructuredGrid::vtkStructuredGrid()
   this->PointVisibility = vtkStructuredVisibilityConstraint::New();
   this->CellVisibility = vtkStructuredVisibilityConstraint::New();
 
-  this->Information->Set(vtkDataObject::DATA_EXTENT_TYPE(), VTK_3D_EXTENT);
-  this->Information->Set(vtkDataObject::DATA_EXTENT(), this->Extent, 6);
-
   int extent[6] = {0, -1, 0, -1, 0, -1};
   memcpy(this->Extent, extent, 6*sizeof(int));
+
+  this->Information->Set(vtkDataObject::DATA_EXTENT_TYPE(), VTK_3D_EXTENT);
+  this->Information->Set(vtkDataObject::DATA_EXTENT(), this->Extent, 6);
 }
 
 //----------------------------------------------------------------------------
 vtkStructuredGrid::~vtkStructuredGrid()
 {
-  this->Initialize();
   this->Vertex->Delete();
   this->Line->Delete();
   this->Quad->Delete();
@@ -86,7 +84,7 @@ vtkStructuredGrid::~vtkStructuredGrid()
 // Copy the geometric and topological structure of an input structured grid.
 void vtkStructuredGrid::CopyStructure(vtkDataSet *ds)
 {
-  vtkStructuredGrid *sg=(vtkStructuredGrid *)ds;
+  vtkStructuredGrid *sg=static_cast<vtkStructuredGrid *>(ds);
   vtkPointSet::CopyStructure(ds);
   int i;
 
@@ -107,6 +105,7 @@ void vtkStructuredGrid::CopyStructure(vtkDataSet *ds)
   this->CellVisibility->ShallowCopy(sg->CellVisibility);
 }
 
+
 //----------------------------------------------------------------------------
 void vtkStructuredGrid::Initialize()
 {
@@ -120,7 +119,7 @@ void vtkStructuredGrid::Initialize()
 
   if(this->Information)
     {
-  this->SetDimensions(0,0,0);
+    this->SetDimensions(0,0,0);
     }
 }
 
@@ -1217,3 +1216,37 @@ vtkStructuredGrid* vtkStructuredGrid::GetData(vtkInformationVector* v, int i)
 {
   return vtkStructuredGrid::GetData(v->GetInformationObject(i));
 }
+
+//----------------------------------------------------------------------------
+void vtkStructuredGrid::GetPoint(int i, int j, int k, double p[3], bool adjustForExtent)
+{
+  int extent[6];
+  this->GetExtent(extent);  
+
+  if(i < extent[0] || i > extent[1] || 
+     j < extent[2] || j > extent[3] || 
+     k < extent[4] || k > extent[5])
+    {
+    return; // out of bounds!
+    }
+  
+  int pos[3];
+  pos[0] = i;
+  pos[1] = j;
+  pos[2] = k;
+
+  vtkIdType id;
+
+  if(adjustForExtent)
+    {
+    id = vtkStructuredData::ComputePointIdForExtent(extent, pos);
+    }
+  else
+    {
+    int dim[3];
+    this->GetDimensions(dim);  
+    id = vtkStructuredData::ComputePointId(dim, pos);
+    }
+
+  this->GetPoint(id, p);  
+}
