@@ -21,12 +21,12 @@
 #include "vtkObjectFactory.h"
 #include "vtkPlane.h"
 #include "vtkPointData.h"
-#include "vtkPointLocator.h"
+#include "vtkIncrementalPointLocator.h"
 #include "vtkPoints.h"
 #include "vtkPolygon.h"
 #include "vtkQuadric.h"
 
-vtkCxxRevisionMacro(vtkTriangle, "$Revision: 1.8 $");
+vtkCxxRevisionMacro(vtkTriangle, "$Revision: 1.11 $");
 vtkStandardNewMacro(vtkTriangle);
 
 //----------------------------------------------------------------------------
@@ -49,6 +49,21 @@ vtkTriangle::~vtkTriangle()
   this->Line->Delete();
 }
 
+//----------------------------------------------------------------------------
+// This function simply calls the static function:
+// vtkTriangle::TriangleArea(double p1[3], double p2[3], double p3[3])
+// with the appropriate parameters from the instantiated vtkTriangle.
+double vtkTriangle::ComputeArea()
+{
+  double p0[3];
+  double p1[3];
+  double p2[3];
+  this->GetPoints()->GetPoint(0, p0);
+  this->GetPoints()->GetPoint(1, p1);
+  this->GetPoints()->GetPoint(2, p2);
+  return vtkTriangle::TriangleArea(p0, p1, p2);
+}
+
 
 //----------------------------------------------------------------------------
 // Create a new cell and copy this triangle's information into the cell.
@@ -365,7 +380,7 @@ int *vtkTriangle::GetEdgeArray(int edgeId)
 
 //----------------------------------------------------------------------------
 void vtkTriangle::Contour(double value, vtkDataArray *cellScalars, 
-                          vtkPointLocator *locator,
+                          vtkIncrementalPointLocator *locator,
                           vtkCellArray *verts, 
                           vtkCellArray *lines, 
                           vtkCellArray *vtkNotUsed(polys), 
@@ -836,7 +851,7 @@ static TRIANGLE_CASES triangleCases[] = {
 // Clip this triangle using scalar value provided. Like contouring, except
 // that it cuts the triangle to produce other triangles.
 void vtkTriangle::Clip(double value, vtkDataArray *cellScalars, 
-                       vtkPointLocator *locator, vtkCellArray *tris,
+                       vtkIncrementalPointLocator *locator, vtkCellArray *tris,
                        vtkPointData *inPd, vtkPointData *outPd,
                        vtkCellData *inCd, vtkIdType cellId, vtkCellData *outCd,
                        int insideOut)
