@@ -28,13 +28,12 @@
 #include "vtkPolyData.h"
 #include "vtkUnstructuredGrid.h"
 
-vtkCxxRevisionMacro(vtkArrayCalculator, "$Revision: 1.43 $");
+vtkCxxRevisionMacro(vtkArrayCalculator, "$Revision: 1.49.4.1 $");
 vtkStandardNewMacro(vtkArrayCalculator);
 
 vtkArrayCalculator::vtkArrayCalculator()
 {
   this->FunctionParser = vtkFunctionParser::New();
-  
   this->Function = NULL;
   this->ResultArrayName = NULL;
   this->SetResultArrayName("resultArray");
@@ -54,7 +53,6 @@ vtkArrayCalculator::vtkArrayCalculator()
   this->SelectedCoordinateScalarComponents = NULL;
   this->SelectedCoordinateVectorComponents = NULL;
   this->CoordinateResults = 0;
-
   this->ReplaceInvalidValues = 0;
   this->ReplacementValue = 0.0;
 
@@ -193,6 +191,7 @@ void vtkArrayCalculator::SetResultArrayName(const char* name)
     return;
     }
   this->Modified();
+  
   if (this->ResultArrayName)
     {
     delete [] this->ResultArrayName;
@@ -211,7 +210,7 @@ int vtkArrayCalculator::RequestData(
   vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
   vtkInformation *outInfo = outputVector->GetInformationObject(0);
 
-  // get the input and ouptut
+  // get the input and output
   vtkDataObject *input = inInfo->Get(vtkDataObject::DATA_OBJECT());
   vtkDataObject *output = outInfo->Get(vtkDataObject::DATA_OBJECT());
 
@@ -279,10 +278,11 @@ int vtkArrayCalculator::RequestData(
     vtkDebugMacro("Empty data.");
     return 1;
     }
-  
+    
   for (i = 0; i < this->NumberOfScalarArrays; i++)
-    {
+    {   
     currentArray = inFD->GetArray(this->ScalarArrayNames[i]);
+    
     if (currentArray)
       {
       if (currentArray->GetNumberOfComponents() >
@@ -380,7 +380,13 @@ int vtkArrayCalculator::RequestData(
       }
     }
 
-  if (this->FunctionParser->IsScalarResult())
+  if ( !this->Function || strlen(this->Function) == 0)
+    {
+    dsOutput->CopyStructure(dsInput);
+    dsOutput->CopyAttributes(dsInput);
+    return 1;
+    }
+  else if (this->FunctionParser->IsScalarResult())
     {
     resultType = 0;
     }
@@ -390,10 +396,13 @@ int vtkArrayCalculator::RequestData(
     }
   else
     {
+    dsOutput->CopyStructure(dsInput);
+    dsOutput->CopyAttributes(dsInput);
     // Error occurred in vtkFunctionParser.
+    vtkWarningMacro("An error occured when parsing the calculator's function.  See previous errors.");
     return 1;
     }
-
+  
   if(resultType == 1 && CoordinateResults != 0 && (psOutput || graphOutput))
     {
     resultPoints = vtkPoints::New();
@@ -431,7 +440,7 @@ int vtkArrayCalculator::RequestData(
     {
     resultArray->Allocate(numTuples * 3);
     resultArray->SetNumberOfComponents(3);
-    resultArray->SetNumberOfTuples(numTuples);
+    resultArray->SetNumberOfTuples(numTuples);    
     resultArray->SetTuple(0, this->FunctionParser->GetVectorResult());
     }
   
