@@ -33,8 +33,9 @@
 #include "vtkCellArray.h"
 #include "vtkIdTypeArray.h"
 #include "vtkUnsignedCharArray.h"
+#include "vtkIncrementalPointLocator.h"
 
-vtkCxxRevisionMacro(vtkClipVolume, "$Revision: 1.73 $");
+vtkCxxRevisionMacro(vtkClipVolume, "$Revision: 1.75 $");
 vtkStandardNewMacro(vtkClipVolume);
 vtkCxxSetObjectMacro(vtkClipVolume,ClipFunction,vtkImplicitFunction);
 
@@ -120,7 +121,7 @@ int vtkClipVolume::RequestData(
   vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
   vtkInformation *outInfo = outputVector->GetInformationObject(0);
 
-  // get the input and ouptut
+  // get the input and output
   vtkImageData *input = vtkImageData::SafeDownCast(
     inInfo->Get(vtkDataObject::DATA_OBJECT()));
   vtkUnstructuredGrid *output = vtkUnstructuredGrid::SafeDownCast(
@@ -648,7 +649,7 @@ void vtkClipVolume::ClipVoxel(double value, vtkDataArray *cellScalars,
 
 // Specify a spatial locator for merging points. By default, 
 // an instance of vtkMergePoints is used.
-void vtkClipVolume::SetLocator(vtkPointLocator *locator)
+void vtkClipVolume::SetLocator(vtkIncrementalPointLocator *locator)
 {
   if ( this->Locator == locator ) 
     {
