@@ -40,6 +40,7 @@
 #include "vtkPassInputTypeAlgorithm.h"
 
 class vtkGraph;
+class vtkTable;
 
 class VTK_GRAPHICS_EXPORT vtkProgrammableFilter : public vtkPassInputTypeAlgorithm
 {
@@ -84,6 +85,11 @@ public:
   // Get the input as a concrete type.
   vtkGraph *GetGraphInput();
 
+  
+  // Description:
+  // Get the input as a concrete type.
+  vtkTable *GetTableInput();
+
   // Description:
   // When CopyArrays is true, all arrays are copied to the output
   // iff input and output are of the same type. False by default.
