@@ -13,17 +13,18 @@
 
 =========================================================================*/
 #include "vtkAbstractParticleWriter.h"
-
-vtkCxxRevisionMacro(vtkAbstractParticleWriter, "$Revision: 1.2 $");
-
+//----------------------------------------------------------------------------
+vtkCxxRevisionMacro(vtkAbstractParticleWriter, "$Revision: 1.3 $");
+//----------------------------------------------------------------------------
 // Construct with no start and end write methods or arguments.
 vtkAbstractParticleWriter::vtkAbstractParticleWriter()
 {
-  this->TimeStep  = 0;
-  this->TimeValue = 0.0;
-  this->FileName  = NULL;
+  this->TimeStep     = 0;
+  this->TimeValue    = 0.0;
+  this->FileName     = NULL;
+  this->CollectiveIO = 0;
 }
-
+//----------------------------------------------------------------------------
 vtkAbstractParticleWriter::~vtkAbstractParticleWriter()
 {
   if (this->FileName)
@@ -32,12 +33,23 @@ vtkAbstractParticleWriter::~vtkAbstractParticleWriter()
     this->FileName = NULL;
     }
 }
-
+//----------------------------------------------------------------------------
+void vtkAbstractParticleWriter::SetWriteModeToCollective()
+{
+  this->SetCollectiveIO(1);
+}
+//----------------------------------------------------------------------------
+void vtkAbstractParticleWriter::SetWriteModeToIndependent()
+{
+  this->SetCollectiveIO(0);
+}
+//----------------------------------------------------------------------------
 void vtkAbstractParticleWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os,indent);
   os << indent << "TimeStep: " << this->TimeStep << endl;
   os << indent << "TimeValue: " << this->TimeValue << endl;
+  os << indent << "CollectiveIO: " << this->CollectiveIO << endl;
   os << indent << "FileName: " << 
     (this->FileName ? this->FileName : "NONE") << endl;
 }
