@@ -108,9 +108,10 @@ public:
 
   // Description:
   // Reads the FORMAT part of the case file to determine whether this is an
-  // EnSight6 or EnSightGold data set.  Returns 0 if the format is EnSight6,
-  // 1 if it is EnSightGold, and -1 otherwise (meaning an error occurred).
-  int DetermineEnSightVersion();
+  // EnSight6 or EnSightGold data set.  Returns an identifier listed in
+  // the FileTypes enum or -1 if an error occurred or the file could not
+  // be indentified as any EnSight type.
+  int DetermineEnSightVersion(int quiet=0);
 
   // Description:
   // Set/get the flag for whether to read all the variables
@@ -194,6 +195,11 @@ public:
   vtkGetMacro(ParticleCoordinatesByIndex, int);
   vtkBooleanMacro(ParticleCoordinatesByIndex, int);
 
+  // Description:
+  // Returns true if the file pointed to by casefilename appears to be a
+  // valid EnSight case file.
+  static int CanReadFile(const char *casefilename);
+
 protected:
   vtkGenericEnSightReader();
   ~vtkGenericEnSightReader();
