@@ -24,20 +24,12 @@
 
 #include <assert.h>
 
-vtkCxxRevisionMacro(vtkXMLPolyDataReader, "$Revision: 1.9 $");
+vtkCxxRevisionMacro(vtkXMLPolyDataReader, "$Revision: 1.12 $");
 vtkStandardNewMacro(vtkXMLPolyDataReader);
 
 //----------------------------------------------------------------------------
 vtkXMLPolyDataReader::vtkXMLPolyDataReader()
 {
-  // Copied from vtkPolyDataReader constructor:
-  vtkPolyData *output = vtkPolyData::New();
-  this->SetOutput(output);
-  // Releasing data for pipeline parallism.
-  // Filters will know it is empty. 
-  output->ReleaseData();
-  output->Delete();
-  
   this->VertElements = 0;
   this->LineElements = 0;
   this->StripElements = 0;
@@ -49,13 +41,13 @@ vtkXMLPolyDataReader::vtkXMLPolyDataReader()
 
   // TimeStep
   this->VertsTimeStep = -1;
-  this->VertsOffset = (unsigned long)-1;
+  this->VertsOffset = static_cast<unsigned long>(-1);
   this->LinesTimeStep = -1;
-  this->LinesOffset = (unsigned long)-1;
+  this->LinesOffset = static_cast<unsigned long>(-1);
   this->StripsTimeStep = -1;
-  this->StripsOffset = (unsigned long)-1;
+  this->StripsOffset = static_cast<unsigned long>(-1);
   this->PolysTimeStep = -1;
-  this->PolysOffset = (unsigned long)-1;
+  this->PolysOffset = static_cast<unsigned long>(-1);
 }
 
 //----------------------------------------------------------------------------
@@ -73,12 +65,6 @@ void vtkXMLPolyDataReader::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
 }
 
-//----------------------------------------------------------------------------
-void vtkXMLPolyDataReader::SetOutput(vtkPolyData *output)
-{
-  this->GetExecutive()->SetOutputData(0, output);
-}
-
 //----------------------------------------------------------------------------
 vtkPolyData* vtkXMLPolyDataReader::GetOutput()
 {
@@ -126,7 +112,13 @@ void vtkXMLPolyDataReader::GetOutputUpdateExtent(int& piece,
                                                  int& numberOfPieces,
                                                  int& ghostLevel)
 {
-  this->GetOutput()->GetUpdateExtent(piece, numberOfPieces, ghostLevel);
+  vtkInformation* outInfo = this->GetCurrentOutputInformation();
+  piece = outInfo->Get(
+      vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER());
+  numberOfPieces= outInfo->Get(
+      vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES());
+  ghostLevel = outInfo->Get(
+      vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS());
 }
 
 //----------------------------------------------------------------------------
@@ -207,7 +199,7 @@ vtkIdType vtkXMLPolyDataReader::GetNumberOfCellsInPiece(int piece)
 void vtkXMLPolyDataReader::SetupOutputData()
 {
   this->Superclass::SetupOutputData();
-  vtkPolyData* output = this->GetOutput();
+  vtkPolyData* output = vtkPolyData::SafeDownCast(this->GetCurrentOutput());
   
   // Setup the output's cell arrays.  
   vtkCellArray* outVerts = vtkCellArray::New();
@@ -345,7 +337,7 @@ int vtkXMLPolyDataReader::ReadPieceData()
     return 0;
     }
   
-  vtkPolyData* output = this->GetOutput();
+  vtkPolyData* output = vtkPolyData::SafeDownCast(this->GetCurrentOutput());
   
   // Set the range of progress for the Verts.
   this->SetProgressRange(progressRange, 1, fractions);
@@ -440,7 +432,7 @@ int vtkXMLPolyDataReader::ReadPieceData()
 
 //----------------------------------------------------------------------------
 int vtkXMLPolyDataReader::ReadArrayForCells(vtkXMLDataElement* da,
-                                            vtkDataArray* outArray)
+                                            vtkAbstractArray* outArray)
 {
   // Split progress range according to the fraction of data that will
   // be read for each type of cell.
@@ -468,9 +460,8 @@ int vtkXMLPolyDataReader::ReadArrayForCells(vtkXMLDataElement* da,
   vtkIdType inStartCell = 0;
   vtkIdType outStartCell = this->StartVert;
   vtkIdType numCells = this->NumberOfVerts[this->Piece];  
-  if(!this->ReadData(da, outArray->GetVoidPointer(outStartCell*components),
-                     outArray->GetDataType(), inStartCell*components,
-                     numCells*components))
+  if(!this->ReadArrayValues(da, outStartCell*components, outArray,
+      inStartCell*components, numCells*components))
     {
     return 0;
     }
@@ -482,9 +473,8 @@ int vtkXMLPolyDataReader::ReadArrayForCells(vtkXMLDataElement* da,
   inStartCell += numCells;
   outStartCell = this->TotalNumberOfVerts + this->StartLine;
   numCells = this->NumberOfLines[this->Piece];  
-  if(!this->ReadData(da, outArray->GetVoidPointer(outStartCell*components),
-                     outArray->GetDataType(), inStartCell*components,
-                     numCells*components))
+  if(!this->ReadArrayValues(da, outStartCell*components, outArray,
+      inStartCell*components, numCells*components))
     {
     return 0;
     }
@@ -497,9 +487,8 @@ int vtkXMLPolyDataReader::ReadArrayForCells(vtkXMLDataElement* da,
   outStartCell = (this->TotalNumberOfVerts + this->TotalNumberOfLines +
                   this->StartStrip);
   numCells = this->NumberOfStrips[this->Piece];  
-  if(!this->ReadData(da, outArray->GetVoidPointer(outStartCell*components),
-                     outArray->GetDataType(), inStartCell*components,
-                     numCells*components))
+  if(!this->ReadArrayValues(da, outStartCell*components, outArray,
+      inStartCell*components, numCells*components))
     {
     return 0;
     }
@@ -512,9 +501,8 @@ int vtkXMLPolyDataReader::ReadArrayForCells(vtkXMLDataElement* da,
   outStartCell = (this->TotalNumberOfVerts + this->TotalNumberOfLines +
                   this->TotalNumberOfStrips + this->StartPoly);
   numCells = this->NumberOfPolys[this->Piece];  
-  if(!this->ReadData(da, outArray->GetVoidPointer(outStartCell*components),
-                     outArray->GetDataType(), inStartCell*components,
-                     numCells*components))
+  if(!this->ReadArrayValues(da, outStartCell*components, outArray,
+      inStartCell*components, numCells*components))
     {
     return 0;
     }
