@@ -30,11 +30,12 @@
 #include "vtkInformationVector.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
+#include "vtkPoints.h"
 #include "vtkSmartPointer.h"
 #include "vtkTree.h"
 #include "vtkTreeDFSIterator.h"
 
-vtkCxxRevisionMacro(vtkBoxLayoutStrategy, "$Revision: 1.7 $");
+vtkCxxRevisionMacro(vtkBoxLayoutStrategy, "$Revision: 1.8 $");
 vtkStandardNewMacro(vtkBoxLayoutStrategy);
 
 vtkBoxLayoutStrategy::vtkBoxLayoutStrategy()
@@ -72,6 +73,10 @@ void vtkBoxLayoutStrategy::Layout(
       {
       coords[0] = 0; coords[1] = 1; coords[2] = 0; coords[3] = 1;
       coordsArray->SetTuple(vertex, coords);
+      inputTree->GetPoints()->SetPoint(vertex,
+        (coords[0] + coords[1])/2.0,
+        (coords[2] + coords[3])/2.0,
+        0.0);
       }
     double doubleCoords[4];
     coordsArray->GetTuple(vertex, doubleCoords);
@@ -129,6 +134,10 @@ void vtkBoxLayoutStrategy::Layout(
             parentMinY + ySpace - yDelta*i;// maxY
 
           coordsArray->SetTuple(child, coords);
+          inputTree->GetPoints()->SetPoint(child,
+            (coords[0] + coords[1])/2.0,
+            (coords[2] + coords[3])/2.0,
+            0.0);
           }
         }
       }
