@@ -41,7 +41,7 @@
 #include "vtkSmartPointer.h"
 #include "vtkTree.h"
 
-vtkCxxRevisionMacro(vtkFast2DLayoutStrategy, "$Revision: 1.22 $");
+vtkCxxRevisionMacro(vtkFast2DLayoutStrategy, "$Revision: 1.24 $");
 vtkStandardNewMacro(vtkFast2DLayoutStrategy);
 
 // This is just a convenient macro for smart pointers
@@ -233,7 +233,7 @@ void vtkFast2DLayoutStrategy::Initialize()
   // Get the weight array
   vtkDataArray* weightArray = NULL;
   double weight, maxWeight = 1;
-  if (this->EdgeWeightField != NULL)
+  if (this->WeightEdges && this->EdgeWeightField != NULL)
     {
     weightArray = vtkDataArray::SafeDownCast(this->Graph->GetEdgeData()->GetAbstractArray(this->EdgeWeightField));
     if (weightArray != NULL)
@@ -293,6 +293,13 @@ void vtkFast2DLayoutStrategy::Layout()
     this->LayoutComplete = 1;
     return;
     }
+
+  // If there are zero or one vertex, we are done
+  if (this->Graph->GetNumberOfVertices() <= 1)
+    {
+    this->LayoutComplete = 1;
+    return;
+    }
     
   // Set my graph as input into the graph to polydata
   this->GraphToPoly->SetInput(this->Graph);
