@@ -23,7 +23,7 @@
 #define VTK_PCA_COMPCOLUMN "PCA"
 
 
-vtkCxxRevisionMacro(vtkPCAStatistics,"$Revision: 1.6 $");
+vtkCxxRevisionMacro(vtkPCAStatistics,"$Revision: 1.12 $");
 vtkStandardNewMacro(vtkPCAStatistics);
 
 const char* vtkPCAStatistics::NormalizationSchemeEnumNames[NUM_NORMALIZATION_SCHEMES + 1] =
@@ -203,17 +203,19 @@ void vtkPCAAssessFunctor::operator () ( vtkVariantArray* result, vtkIdType row )
 // ======================================================== vtkPCAStatistics
 vtkPCAStatistics::vtkPCAStatistics()
 {
-  this->SetNumberOfInputPorts( 3 ); // last port is for normalization coefficients.
+  this->SetNumberOfInputPorts( 4 ); // last port is for normalization coefficients.
   this->NormalizationScheme = NONE;
   this->BasisScheme = FULL_BASIS;
   this->FixedBasisSize = -1;
   this->FixedBasisEnergy = 1.;
 }
 
+// ----------------------------------------------------------------------
 vtkPCAStatistics::~vtkPCAStatistics()
 {
 }
 
+// ----------------------------------------------------------------------
 void vtkPCAStatistics::PrintSelf( ostream& os, vtkIndent indent )
 {
   this->Superclass::PrintSelf( os, indent );
@@ -223,6 +225,43 @@ void vtkPCAStatistics::PrintSelf( ostream& os, vtkIndent indent )
   os << indent << "FixedBasisEnergy: " << this->FixedBasisEnergy << "\n";
 }
 
+// ----------------------------------------------------------------------
+bool vtkPCAStatistics::SetParameter( const char* parameter,
+                                     int vtkNotUsed( index ),
+                                     vtkVariant value )
+{
+  if ( ! strcmp( parameter, "NormalizationScheme" ) )
+    {
+    this->SetNormalizationScheme( value.ToInt() );
+
+    return true;
+    }
+
+  if ( ! strcmp( parameter, "BasisScheme" ) )
+    {
+    this->SetBasisScheme( value.ToInt() );
+
+    return true;
+    }
+
+  if ( ! strcmp( parameter, "FixedBasisSize" ) )
+    {
+    this->SetFixedBasisSize( value.ToInt() );
+
+    return true;
+    }
+
+  if ( ! strcmp( parameter, "FixedBasisEnergy" ) )
+    {
+    this->SetFixedBasisEnergy( value.ToDouble() );
+
+    return true;
+    }
+
+  return false;
+}
+
+// ----------------------------------------------------------------------
 const char* vtkPCAStatistics::GetNormalizationSchemeName( int schemeIndex )
 {
   if ( schemeIndex < 0 || schemeIndex > NUM_NORMALIZATION_SCHEMES )
@@ -232,6 +271,7 @@ const char* vtkPCAStatistics::GetNormalizationSchemeName( int schemeIndex )
   return vtkPCAStatistics::NormalizationSchemeEnumNames[schemeIndex];
 }
 
+// ----------------------------------------------------------------------
 void vtkPCAStatistics::SetNormalizationSchemeByName( const char* schemeName )
 {
   for ( int i = 0; i < NUM_NORMALIZATION_SCHEMES; ++ i )
@@ -246,16 +286,18 @@ void vtkPCAStatistics::SetNormalizationSchemeByName( const char* schemeName )
 }
 
 
+// ----------------------------------------------------------------------
 vtkTable* vtkPCAStatistics::GetSpecifiedNormalization()
 {
-  return vtkTable::SafeDownCast( this->GetInputDataObject( 2, 0 ) );
+  return vtkTable::SafeDownCast( this->GetInputDataObject( 3, 0 ) );
 }
 
 void vtkPCAStatistics::SetSpecifiedNormalization( vtkTable* normSpec )
 {
-  this->SetInput( 2, normSpec );
+  this->SetInput( 3, normSpec );
 }
 
+// ----------------------------------------------------------------------
 const char* vtkPCAStatistics::GetBasisSchemeName( int schemeIndex )
 {
   if ( schemeIndex < 0 || schemeIndex > NUM_BASIS_SCHEMES )
@@ -265,6 +307,7 @@ const char* vtkPCAStatistics::GetBasisSchemeName( int schemeIndex )
   return vtkPCAStatistics::BasisSchemeEnumNames[schemeIndex];
 }
 
+// ----------------------------------------------------------------------
 void vtkPCAStatistics::SetBasisSchemeByName( const char* schemeName )
 {
   for ( int i = 0; i < NUM_BASIS_SCHEMES; ++ i )
@@ -278,9 +321,10 @@ void vtkPCAStatistics::SetBasisSchemeByName( const char* schemeName )
   vtkErrorMacro( "Invalid basis scheme name \"" << schemeName << "\" provided." );
 }
 
+// ----------------------------------------------------------------------
 int vtkPCAStatistics::FillInputPortInformation( int port, vtkInformation* info )
 {
-  if ( port == 2 )
+  if ( port == 3 )
     {
     info->Set( vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkTable" );
     info->Set( vtkAlgorithm::INPUT_IS_OPTIONAL(), 1 );
@@ -289,6 +333,7 @@ int vtkPCAStatistics::FillInputPortInformation( int port, vtkInformation* info )
   return this->Superclass::FillInputPortInformation( port, info );
 }
 
+// ----------------------------------------------------------------------
 static void vtkPCAStatisticsNormalizeSpec( vtkVariantArray* normData, 
                                            ap::real_2d_array& cov,
                                            vtkTable* normSpec, 
@@ -406,6 +451,7 @@ static void vtkPCAStatisticsNormalizeSpec( vtkVariantArray* normData,
     }
 }
 
+// ----------------------------------------------------------------------
 static void vtkPCAStatisticsNormalizeVariance( vtkVariantArray* normData, 
                                                ap::real_2d_array& cov )
 {
@@ -431,7 +477,8 @@ static void vtkPCAStatisticsNormalizeVariance( vtkVariantArray* normData,
     }
 }
 
-void vtkPCAStatistics::ExecuteDerive( vtkDataObject* inMetaDO )
+// ----------------------------------------------------------------------
+void vtkPCAStatistics::Derive( vtkDataObject* inMetaDO )
 {
   vtkMultiBlockDataSet* inMeta = vtkMultiBlockDataSet::SafeDownCast( inMetaDO );
   if ( ! inMeta )
@@ -444,7 +491,7 @@ void vtkPCAStatistics::ExecuteDerive( vtkDataObject* inMetaDO )
     }
 
   // Use the parent class to compute a covariance matrix for each request.
-  this->Superclass::ExecuteDerive( inMeta );
+  this->Superclass::Derive( inMeta );
 
   // Now that we have the covariance matrices, compute the SVD of each.
   vtkIdType nb = static_cast<vtkIdType>( inMeta->GetNumberOfBlocks() );
@@ -569,10 +616,10 @@ void vtkPCAStatistics::ExecuteDerive( vtkDataObject* inMetaDO )
     }
 }
 
-void vtkPCAStatistics::ExecuteAssess( vtkTable* inData, 
-                                      vtkDataObject* inMetaDO, 
-                                      vtkTable* outData, 
-                                      vtkDataObject* vtkNotUsed(outMetaDO) )
+// ----------------------------------------------------------------------
+void vtkPCAStatistics::Assess( vtkTable* inData, 
+                               vtkDataObject* inMetaDO, 
+                               vtkTable* outData )
 {
   vtkMultiBlockDataSet* inMeta = vtkMultiBlockDataSet::SafeDownCast( inMetaDO );
   if ( ! inMeta || ! outData )
@@ -661,6 +708,7 @@ void vtkPCAStatistics::ExecuteAssess( vtkTable* inData,
     }
 }
 
+// ----------------------------------------------------------------------
 void vtkPCAStatistics::SelectAssessFunctor( vtkTable* inData, 
                                             vtkDataObject* inMetaDO,
                                             vtkStringArray* vtkNotUsed(rowNames), 
