@@ -86,7 +86,7 @@
 
 //----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkEnSightWriter);
-vtkCxxRevisionMacro(vtkEnSightWriter, "$Revision: 1.5 $");
+vtkCxxRevisionMacro(vtkEnSightWriter, "$Revision: 1.7 $");
 
 vtkCxxSetObjectMacro(vtkEnSightWriter, ModelMetadata, vtkModelMetadata);
 
@@ -564,26 +564,36 @@ void vtkEnSightWriter::WriteData()
     elementTypes.push_back(VTK_LINE);
     elementTypes.push_back(VTK_TRIANGLE);
     elementTypes.push_back(VTK_QUAD);
+    elementTypes.push_back(VTK_POLYGON);
     elementTypes.push_back(VTK_TETRA);
     elementTypes.push_back(VTK_HEXAHEDRON);
+    elementTypes.push_back(VTK_WEDGE);
     elementTypes.push_back(VTK_PYRAMID);
+    elementTypes.push_back(VTK_CONVEX_POINT_SET);
     elementTypes.push_back(VTK_QUADRATIC_EDGE);
     elementTypes.push_back(VTK_QUADRATIC_TRIANGLE);
     elementTypes.push_back(VTK_QUADRATIC_QUAD);
     elementTypes.push_back(VTK_QUADRATIC_TETRA);
     elementTypes.push_back(VTK_QUADRATIC_HEXAHEDRON);
+    elementTypes.push_back(VTK_QUADRATIC_WEDGE);
+    elementTypes.push_back(VTK_QUADRATIC_PYRAMID);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_VERTEX);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_LINE);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_TRIANGLE);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_QUAD);
+    elementTypes.push_back(this->GhostLevelMultiplier+VTK_POLYGON);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_TETRA);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_HEXAHEDRON);
+    elementTypes.push_back(this->GhostLevelMultiplier+VTK_WEDGE);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_PYRAMID);
+    elementTypes.push_back(this->GhostLevelMultiplier+VTK_CONVEX_POINT_SET);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_QUADRATIC_EDGE);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_QUADRATIC_TRIANGLE);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_QUADRATIC_QUAD);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_QUADRATIC_TETRA);
     elementTypes.push_back(this->GhostLevelMultiplier+VTK_QUADRATIC_HEXAHEDRON);
+    elementTypes.push_back(this->GhostLevelMultiplier+VTK_QUADRATIC_WEDGE);
+    elementTypes.push_back(this->GhostLevelMultiplier+VTK_QUADRATIC_PYRAMID);
 
     //write out each type of element
     if (this->ShouldWriteGeometry())
@@ -630,29 +640,30 @@ void vtkEnSightWriter::WriteData()
       //figure out what type of data it is
       int DataSize=DataArray->GetNumberOfComponents();
 
-      for (int CurrentDimension=0;
-        CurrentDimension<DataSize;
-        CurrentDimension++)
+      for (unsigned int k=0;k<elementTypes.size();k++)
         {
-        for (unsigned int k=0;k<elementTypes.size();k++)
+        if (CellsByElement[elementTypes[k]].size()>0)
           {
-          if (CellsByElement[elementTypes[k]].size()>0)
+          this->WriteElementTypeToFile(elementTypes[k],
+            cellArrayFiles[j]);
+          for (unsigned int m=0;m<CellsByElement[elementTypes[k]].size();m++)
             {
-            this->WriteElementTypeToFile(elementTypes[k],
-              cellArrayFiles[j]);
-            for (unsigned int m=0;m<CellsByElement[elementTypes[k]].size();m++)
+            for ( int CurrentDimension = 0; CurrentDimension < DataSize;
+                     CurrentDimension ++ )
               {
               this->WriteFloatToFile
-                ((float)(DataArray->GetTuple(CellsByElement[elementTypes[k]]
-                                             [m])[CurrentDimension]),
-                 cellArrayFiles[j]);
+                (  (float) 
+                   (   DataArray
+                       ->GetTuple(  CellsByElement[ elementTypes[k] ][m]  )
+                         [CurrentDimension]
+                   ),
+                   cellArrayFiles[j]
+                );
               }
             }
           }
         }
       }
-
-
     }
 
   //now write the empty blocks
@@ -1038,15 +1049,24 @@ void vtkEnSightWriter::WriteElementTypeToFile(int elementType,FILE* fd)
     case(VTK_QUAD):
       this->WriteStringToFile("quad4",fd);
       break;
+    case(VTK_POLYGON):
+      this->WriteStringToFile("nsided",fd);
+      break;
     case(VTK_TETRA):
       this->WriteStringToFile("tetra4",fd);
       break;
     case(VTK_HEXAHEDRON):
       this->WriteStringToFile("hexa8",fd);
       break;
+    case(VTK_WEDGE):
+      this->WriteStringToFile("penta6",fd);
+      break;
     case(VTK_PYRAMID):
       this->WriteStringToFile("pyramid5",fd);
       break;
+    case(VTK_CONVEX_POINT_SET):
+      this->WriteStringToFile("nfaced",fd);
+      break;
     case(VTK_QUADRATIC_EDGE):
       this->WriteStringToFile("bar3",fd);
       break;
@@ -1062,6 +1082,9 @@ void vtkEnSightWriter::WriteElementTypeToFile(int elementType,FILE* fd)
     case(VTK_QUADRATIC_HEXAHEDRON):
       this->WriteStringToFile("hexa20",fd);
       break;
+    case(VTK_QUADRATIC_WEDGE):
+      this->WriteStringToFile("penta15",fd);
+      break;
     case(VTK_QUADRATIC_PYRAMID):
       this->WriteStringToFile("pyramid13",fd);
       break;
@@ -1083,15 +1106,24 @@ void vtkEnSightWriter::WriteElementTypeToFile(int elementType,FILE* fd)
     case(VTK_QUAD):
       this->WriteStringToFile("g_quad4",fd);
       break;
+    case(VTK_POLYGON):
+      this->WriteStringToFile("g_nsided",fd);
+      break;
     case(VTK_TETRA):
       this->WriteStringToFile("g_tetra4",fd);
       break;
     case(VTK_HEXAHEDRON):
       this->WriteStringToFile("g_hexa8",fd);
       break;
+    case(VTK_WEDGE):
+      this->WriteStringToFile("g_penta6",fd);
+      break;
     case(VTK_PYRAMID):
       this->WriteStringToFile("g_pyramid5",fd);
       break;
+    case(VTK_CONVEX_POINT_SET):
+      this->WriteStringToFile("g_nfaced",fd);
+      break;
     case(VTK_QUADRATIC_EDGE):
       this->WriteStringToFile("g_bar3",fd);
       break;
@@ -1107,6 +1139,9 @@ void vtkEnSightWriter::WriteElementTypeToFile(int elementType,FILE* fd)
     case(VTK_QUADRATIC_HEXAHEDRON):
       this->WriteStringToFile("g_hexa20",fd);
       break;
+    case(VTK_QUADRATIC_WEDGE):
+      this->WriteStringToFile("g_penta15",fd);
+      break;
     case(VTK_QUADRATIC_PYRAMID):
       this->WriteStringToFile("g_pyramid13",fd);
       break;
