@@ -23,6 +23,9 @@
 // This is just a test program so that CMake can determine if
 // glXGetProcAddressARB needs to be declared.
 
+#define GLX_GLXEXT_LEGACY
+#define GL_GLEXT_LEGACY
+#include <GL/gl.h>
 #include <GL/glx.h>
 
 int main(int, char **)
