@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# Time-stamp: <2005-06-23 17:26:59 barre>
+# Time-stamp: <2009-07-15 11:27:00 barre>
 #
 # Convert VTK headers to doxygen format
 #
@@ -109,10 +109,12 @@ $PROGNAME =~ s/^.*[\\\/]//;
 
 my %default = 
   (
-   dirs => ["../../Common",
+   dirs => ["../../Charts",
+            "../../Common",
             "../../Filtering",
             "../../GenericFiltering",
             "../../GenericFiltering/Testing/Cxx",
+            "../../Geovis",
             "../../Graphics",
             "../../GUISupport/MFC",
             "../../GUISupport/Qt",
@@ -121,10 +123,11 @@ my %default =
             "../../Infovis",
             "../../IO",
             "../../Parallel",
-            "../../Patented",
             "../../Rendering",
+            "../../TextAnalysis",
             "../../Views",
-            "../../VolumeRendering"],
+            "../../VolumeRendering",
+            "../../Widgets"],
    relativeto => "",
    temp => "doc_header2doxygen.tmp",
    to => "../../../VTK-doxygen"
@@ -270,13 +273,13 @@ foreach my $source (@files) {
         last if $line =~ /\/\/ \.NAME/;
 
         # Date. Example:
-        # Date:      $Date: 2007-08-14 13:46:35 $
+        # Date:      $Date: 2009-12-01 16:10:13 $
 
         if ($line =~ /^\s*Date:\s*(.*)$/) {
             $date = $1;
 
         # Version. Example:
-        # Version:   $Revision: 1.15 $
+        # Version:   $Revision: 1.19 $
 
         } elsif ($line =~ /^\s*Version:\s*(.*)$/) {
             $revision = $1;
