@@ -10,18 +10,17 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: default.h,v 1.2 2008-01-23 20:16:05 barre Exp $
+ * RCS: @(#) $Id: default.h,v 1.1 2007-01-11 00:52:51 barre Exp $
  */
 
 #ifndef _DEFAULT
 #define _DEFAULT
 
-#if defined(__WIN32__) || defined(_WIN32) || \
-    defined(__CYGWIN__) || defined(__MINGW32__)
+#if defined(__WIN32__) || defined(_WIN32)
 #   include "tkWinDefault.h"
 #else
-#   if defined(MAC_OSX_TK)
-#  include "tkMacOSXDefault.h"
+#   if defined(MAC_TCL)
+#  include "tkMacDefault.h"
 #   else
 #  include "tkUnixDefault.h"
 #   endif
