@@ -51,7 +51,7 @@
 *
 * revision history - 
 *
-*  $Id: excn2s.c,v 1.11 2009-01-16 14:32:01 utkarsh Exp $
+*  $Id: excn2s.c,v 1.14 2010-03-01 21:13:21 ndfabia Exp $
 *
 *****************************************************************************/
 
@@ -124,20 +124,21 @@
 int ex_cvt_nodes_to_sides(int exoid,
                           int *num_elem_per_set,
                           int *num_nodes_per_set,
-                          int *side_sets_elem_index,
-                          int *side_sets_node_index,
+                          int * side_sets_elem_index, /* unused */ 
+                          int * side_sets_node_index, /* unused */
                           int *side_sets_elem_list,
                           int *side_sets_node_list,
                           int *side_sets_side_list)
 {
-  int i, j, k, m, n;
+  size_t m;
+  int i, j, k, n;
   int  num_side_sets, num_elem_blks;
   int tot_num_elem = 0, tot_num_ss_elem = 0, elem_num = 0, ndim;
-  int *elem_blk_ids, *connect = 0;
+  int *elem_blk_ids, *connect;
   int *ss_elem_ndx, *ss_elem_node_ndx, *ss_parm_ndx;
   int elem_ctr, node_ctr, elem_num_pos;
   int num_elem_in_blk, num_nodes_per_elem, num_node_per_side, num_attr;
-  int *same_elem_type, el_type = -1;
+  int *same_elem_type, el_type;
   float fdum;
   char *cdum, elem_type[MAX_STR_LENGTH+1];
 
@@ -329,26 +330,26 @@ int ex_cvt_nodes_to_sides(int exoid,
     elem_blk_parms[i].num_nodes_per_elem = num_nodes_per_elem;
     elem_blk_parms[i].num_attr = num_attr;
 
-    for (m=0; m < (int)strlen(elem_type); m++)
-      elem_blk_parms[i].elem_type[m] = (char)
-              toupper((int)elem_type[m]);
+    for (m=0; m < strlen(elem_type); m++)
+      elem_blk_parms[i].elem_type[m] = 
+              (char)toupper(elem_type[m]);
     elem_blk_parms[i].elem_type[m] = '\0';
 
     if (strncmp(elem_blk_parms[i].elem_type,"CIRCLE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = CIRCLE;
+      elem_blk_parms[i].elem_type_val = EX_EL_CIRCLE;
       /* set side set node stride */
         elem_blk_parms[i].num_nodes_per_side[0] = 1;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"SPHERE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = SPHERE;
+      elem_blk_parms[i].elem_type_val = EX_EL_SPHERE;
       /* set side set node stride */
         elem_blk_parms[i].num_nodes_per_side[0] = 1;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"QUAD",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = QUAD;
+      elem_blk_parms[i].elem_type_val = EX_EL_QUAD;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 4)
         elem_blk_parms[i].num_nodes_per_side[0] = 2;
@@ -359,7 +360,7 @@ int ex_cvt_nodes_to_sides(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"TRIANGLE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = TRIANGLE;
+      elem_blk_parms[i].elem_type_val = EX_EL_TRIANGLE;
       /* determine side set node stride */
       if (ndim == 2)  /* 2d TRIs */
       {
@@ -370,20 +371,20 @@ int ex_cvt_nodes_to_sides(int exoid,
       }
       else if (ndim == 3)  /* 3d TRIs */
       {
-        elem_blk_parms[i].elem_type_val = TRISHELL;
+        elem_blk_parms[i].elem_type_val = EX_EL_TRISHELL;
         elem_blk_parms[i].num_nodes_per_side[0] =
           elem_blk_parms[i].num_nodes_per_elem;
       }
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"SHELL",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = SHELL;
+      elem_blk_parms[i].elem_type_val = EX_EL_SHELL;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 2)
       {
         /* 2d SHELL; same as BEAM or TRUSS or BAR */
         elem_blk_parms[i].num_nodes_per_side[0] = 2;
-        elem_blk_parms[i].elem_type_val = BEAM;
+        elem_blk_parms[i].elem_type_val = EX_EL_BEAM;
       }
       else if (elem_blk_parms[i].num_nodes_per_elem == 4)
         elem_blk_parms[i].num_nodes_per_side[0] = 4;
@@ -392,7 +393,7 @@ int ex_cvt_nodes_to_sides(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"HEX",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = HEX;
+      elem_blk_parms[i].elem_type_val = EX_EL_HEX;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 8)
         elem_blk_parms[i].num_nodes_per_side[0] = 4;
@@ -407,7 +408,7 @@ int ex_cvt_nodes_to_sides(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"TETRA",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = TETRA;
+      elem_blk_parms[i].elem_type_val = EX_EL_TETRA;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 4)
         elem_blk_parms[i].num_nodes_per_side[0] = 3;
@@ -418,7 +419,7 @@ int ex_cvt_nodes_to_sides(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"WEDGE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = WEDGE;
+      elem_blk_parms[i].elem_type_val = EX_EL_WEDGE;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 6)
         elem_blk_parms[i].num_nodes_per_side[0] = 4;
@@ -432,7 +433,7 @@ int ex_cvt_nodes_to_sides(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"PYRAMID",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = PYRAMID;
+      elem_blk_parms[i].elem_type_val = EX_EL_PYRAMID;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 5)
         elem_blk_parms[i].num_nodes_per_side[0] = 4;
@@ -446,7 +447,7 @@ int ex_cvt_nodes_to_sides(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"BEAM",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = BEAM;
+      elem_blk_parms[i].elem_type_val = EX_EL_BEAM;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 2)
         elem_blk_parms[i].num_nodes_per_side[0] = 2;
@@ -457,7 +458,7 @@ int ex_cvt_nodes_to_sides(int exoid,
               (strncmp(elem_blk_parms[i].elem_type,"BAR",3) == 0)  ||
               (strncmp(elem_blk_parms[i].elem_type,"EDGE",3) == 0) )
     {
-      elem_blk_parms[i].elem_type_val = TRUSS;
+      elem_blk_parms[i].elem_type_val = EX_EL_TRUSS;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 2)
         elem_blk_parms[i].num_nodes_per_side[0] = 2;
@@ -466,14 +467,14 @@ int ex_cvt_nodes_to_sides(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"NULL",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = NULL_ELEMENT;
+      elem_blk_parms[i].elem_type_val = EX_EL_NULL_ELEMENT;
       /* set side set node stride */
       elem_blk_parms[i].num_nodes_per_side[0] = 0;
     }
     else
     { /* unsupported element type; no problem if no sides specified for
          this element block */
-      elem_blk_parms[i].elem_type_val = UNK;
+      elem_blk_parms[i].elem_type_val = EX_EL_UNK;
       elem_blk_parms[i].num_nodes_per_side[0] = 0;
     }
     elem_blk_parms[i].elem_blk_id = elem_blk_ids[i];    /* save id */
@@ -538,12 +539,12 @@ int ex_cvt_nodes_to_sides(int exoid,
       if (side_sets_elem_list[i] <= elem_blk_parms[j].elem_ctr) break;
     }
 
-    if ( i == 0 ) {
+    if (i==0) {
       el_type = elem_blk_parms[j].elem_type_val;
     } 
 
     /* determine which side set this element is in; assign to kth side set */
-    if ( i >= elem_ctr ) {
+    if (i >= elem_ctr) {
       elem_ctr += num_elem_per_set[++k];
       el_type = elem_blk_parms[j].elem_type_val;
       same_elem_type[k] = TRUE;
@@ -667,23 +668,23 @@ int ex_cvt_nodes_to_sides(int exoid,
       {
         switch (elem_blk_parms[ss_parm_ndx[ss_elem_ndx[j]]].elem_type_val)
         {
-          case CIRCLE:
-          case SPHERE:
+          case EX_EL_CIRCLE:
+          case EX_EL_SPHERE:
           {
             /* simple case: 1st node number is same as side # */
                 side_sets_side_list[ss_elem_ndx[j]] = n+1;
             break;
           }
-          case QUAD:
-          case TRIANGLE:
-          case TRUSS:
-          case BEAM:
+          case EX_EL_QUAD:
+          case EX_EL_TRIANGLE:
+          case EX_EL_TRUSS:
+          case EX_EL_BEAM:
           {
             /* simple case: 1st node number is same as side # */
                 side_sets_side_list[ss_elem_ndx[j]] = n+1;
             break;
           }
-          case TRISHELL:
+          case EX_EL_TRISHELL:
           {
             /* use table to find which node to compare to next */
             num_node_per_side = ss_elem_node_ndx[ss_elem_ndx[j]+1] - 
@@ -731,7 +732,7 @@ int ex_cvt_nodes_to_sides(int exoid,
             break;
 
           }
-          case SHELL:
+          case EX_EL_SHELL:
           {
             /* use table to find which node to compare to next */
 
@@ -792,7 +793,7 @@ int ex_cvt_nodes_to_sides(int exoid,
             break;
 
           }
-          case HEX:
+          case EX_EL_HEX:
           {
             /* use table to find which node to compare to next */
           
@@ -828,7 +829,7 @@ int ex_cvt_nodes_to_sides(int exoid,
             }
             break;
           }
-          case TETRA:
+          case EX_EL_TETRA:
           {
             /* use table to find which node to compare to next */
           
@@ -864,7 +865,7 @@ int ex_cvt_nodes_to_sides(int exoid,
             }
             break;
           }
-          case PYRAMID:
+          case EX_EL_PYRAMID:
           {
  /* NOTE: PYRAMID elements in side set node lists are currently not supported */
             exerrval = EX_BADPARAM;
@@ -880,7 +881,7 @@ int ex_cvt_nodes_to_sides(int exoid,
             free(ss_elem_ndx);
             return (EX_FATAL);
           }
-          case WEDGE:
+          case EX_EL_WEDGE:
           {
 #if 1
  /* NOTE: WEDGE elements in side set node lists are currently not supported */
