@@ -36,12 +36,6 @@
 *
 * exgsnl - ex_get_side_set_node_list_len
 *
-* author - Sandia National Laboratories
-*          Vic Yarberry    - Original
-*
-*
-* environment - UNIX
-*
 * entry conditions - 
 *   input parameters:
 *       int     exoid                   exodus file id
@@ -52,7 +46,7 @@
 *
 * revision history - 
 *
-*  $Id: exgsnl.c,v 1.6 2006-11-30 00:59:33 dcthomp Exp $
+*  $Id: exgsnl.c,v 1.7 2010-03-01 19:26:42 ndfabia Exp $
 *
 *****************************************************************************/
 
@@ -62,19 +56,20 @@
 #include "exodusII.h"
 #include "exodusII_int.h"
 
-/*
+/*!
  * This routine is designed to read the Exodus II V 2.0 side set side 
  * definition  and return the length of a ExodusI style side set node list.
-
-
-
+ * \param           exoid                   exodus file id
+ * \param           side_set_id             side set id
+ * \param[out]     *side_set_node_list_len length of node list
  */
 
 int ex_get_side_set_node_list_len(int exoid,
                           int side_set_id,
                           int *side_set_node_list_len)
 {
-  int i, j, m;
+  int i, j;
+  size_t m;
   int  num_side_sets, num_elem_blks, num_df, ndim;
   int tot_num_elem = 0, tot_num_ss_elem = 0; 
   int *elem_blk_ids;
@@ -85,17 +80,7 @@ int ex_get_side_set_node_list_len(int exoid,
   float fdum;
   char *cdum, elem_type[MAX_STR_LENGTH+1];
 
-  struct elem_blk_parm
-  {
-    char elem_type[MAX_STR_LENGTH+1];
-    int elem_blk_id;
-    int num_elem_in_blk;
-    int num_nodes_per_elem;
-    int num_nodes_per_side;
-    int num_attr;
-    int elem_ctr;
-    int elem_type_val;
-  } *elem_blk_parms;
+  struct elem_blk_parm  *elem_blk_parms;
 
   char errmsg[MAX_ERR_LENGTH];
 
@@ -107,6 +92,33 @@ int ex_get_side_set_node_list_len(int exoid,
 /* first check if any side sets are specified */
 /* inquire how many side sets have been stored */
 
+  /* get the dimensionality of the coordinates;  this is necessary to
+     distinguish between 2d TRIs and 3d TRIs */
+
+  if ((ex_inquire(exoid, EX_INQ_DIM, &ndim, &fdum, cdum)) == -1)
+  {
+    sprintf(errmsg,
+           "Error: failed to get dimensionality in file id %d",exoid);
+    ex_err("ex_get_side_set_node_list_len",errmsg,exerrval);
+    return(EX_FATAL);
+  }
+
+  if ((ex_inquire(exoid, EX_INQ_ELEM, &tot_num_elem, &fdum, cdum)) == -1)
+  {
+    sprintf(errmsg,
+           "Error: failed to get total number of elements in file id %d",exoid);
+    ex_err("ex_get_side_set_node_list_len",errmsg,exerrval);
+    return(EX_FATAL);
+  }
+
+  if ((ex_inquire(exoid, EX_INQ_ELEM_BLK, &num_elem_blks, &fdum, cdum)) == -1)
+  {
+    sprintf(errmsg,
+           "Error: failed to get number of element blocks in file id %d",exoid);
+    ex_err("ex_get_side_set_node_list_len",errmsg,exerrval);
+    return(EX_FATAL);
+  }
+
   if ((ex_inquire(exoid, EX_INQ_SIDE_SETS, &num_side_sets, &fdum, cdum)) == -1)
   {
     sprintf(errmsg,
@@ -123,33 +135,6 @@ int ex_get_side_set_node_list_len(int exoid,
     return(EX_WARN);
   }
 
-  if ((ex_inquire(exoid, EX_INQ_ELEM_BLK, &num_elem_blks, &fdum, cdum)) == -1)
-  {
-    sprintf(errmsg,
-           "Error: failed to get number of element blocks in file id %d",exoid);
-    ex_err("ex_get_side_set_node_list_len",errmsg,exerrval);
-    return(EX_FATAL);
-  }
-
-  if ((ex_inquire(exoid, EX_INQ_ELEM, &tot_num_elem, &fdum, cdum)) == -1)
-  {
-    sprintf(errmsg,
-           "Error: failed to get total number of elements in file id %d",exoid);
-    ex_err("ex_get_side_set_node_list_len",errmsg,exerrval);
-    return(EX_FATAL);
-  }
-
-/* get the dimensionality of the coordinates;  this is necessary to
-   distinguish between 2d TRIs and 3d TRIs */
-
-  if ((ex_inquire(exoid, EX_INQ_DIM, &ndim, &fdum, cdum)) == -1)
-  {
-    sprintf(errmsg,
-           "Error: failed to get dimensionality in file id %d",exoid);
-    ex_err("ex_get_side_set_node_list_len",errmsg,exerrval);
-    return(EX_FATAL);
-  }
-
   /* First determine the  # of elements in the side set*/
   if ((ex_get_side_set_param(exoid,side_set_id,&tot_num_ss_elem,&num_df)) == -1)
   {
@@ -163,6 +148,13 @@ int ex_get_side_set_node_list_len(int exoid,
   if (tot_num_ss_elem == 0) /* NULL side set? */
     return (EX_NOERR); /* return zero */
 
+  /* Minor optimization/kluge -- If num_df is nonzero, then assume
+     that it matches the number of nodes in the sideset... */
+  if (num_df > 0) {
+    *side_set_node_list_len = num_df;
+    return(EX_NOERR);
+  }
+
   /* Allocate space for the side set element list */
   if (!(side_set_elem_list=malloc(tot_num_ss_elem*sizeof(int))))
   {
@@ -288,139 +280,138 @@ int ex_get_side_set_node_list_len(int exoid,
     elem_blk_parms[i].num_attr = num_attr;
     elem_blk_parms[i].elem_blk_id = elem_blk_ids[i];
 
-    for (m=0; m < (int)strlen(elem_type); m++)
-      elem_blk_parms[i].elem_type[m] = (char)
-              toupper((int)elem_type[m]);
-    elem_blk_parms[i].elem_type[m] = '\0';
+    for (m=0; m < strlen(elem_type); m++)
+      elem_blk_parms[i].elem_type[m] = toupper(elem_type[m]);
+    elem_blk_parms[i].elem_type[m] = EX_EL_NULL_ELEMENT;
 
     if (strncmp(elem_blk_parms[i].elem_type,"CIRCLE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = CIRCLE;
+      elem_blk_parms[i].elem_type_val = EX_EL_CIRCLE;
       /* set side set node stride */
-        elem_blk_parms[i].num_nodes_per_side = 1;
+        elem_blk_parms[i].num_nodes_per_side[0] = 1;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"SPHERE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = SPHERE;
+      elem_blk_parms[i].elem_type_val = EX_EL_SPHERE;
       /* set side set node stride */
-        elem_blk_parms[i].num_nodes_per_side = 1;
+        elem_blk_parms[i].num_nodes_per_side[0] = 1;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"QUAD",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = QUAD;
+      elem_blk_parms[i].elem_type_val = EX_EL_QUAD;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 4)
-        elem_blk_parms[i].num_nodes_per_side = 2;
+        elem_blk_parms[i].num_nodes_per_side[0] = 2;
       else if (elem_blk_parms[i].num_nodes_per_elem == 5)
-        elem_blk_parms[i].num_nodes_per_side = 2;
+        elem_blk_parms[i].num_nodes_per_side[0] = 2;
       else 
-        elem_blk_parms[i].num_nodes_per_side = 3;
+        elem_blk_parms[i].num_nodes_per_side[0] = 3;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"TRIANGLE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = TRIANGLE;
+      elem_blk_parms[i].elem_type_val = EX_EL_TRIANGLE;
       /* determine side set node stride */
       if (ndim == 2) /* 2d TRIs */
       {
         if (elem_blk_parms[i].num_nodes_per_elem == 3)
-          elem_blk_parms[i].num_nodes_per_side = 2;
+          elem_blk_parms[i].num_nodes_per_side[0] = 2;
         else 
-          elem_blk_parms[i].num_nodes_per_side = 3;
+          elem_blk_parms[i].num_nodes_per_side[0] = 3;
       }
       else if (ndim == 3)  /* 3d TRIs */
       {   /* set the default number of nodes per side; catch exceptions later */
         if (elem_blk_parms[i].num_nodes_per_elem == 3)
-          elem_blk_parms[i].num_nodes_per_side = 3;
+          elem_blk_parms[i].num_nodes_per_side[0] = 3;
         else 
-          elem_blk_parms[i].num_nodes_per_side = 6;
+          elem_blk_parms[i].num_nodes_per_side[0] = 6;
       }
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"SHELL",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = SHELL;
+      elem_blk_parms[i].elem_type_val = EX_EL_SHELL;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 2) /* KLUDGE for 2D Shells*/
-        elem_blk_parms[i].num_nodes_per_side = 2;
+        elem_blk_parms[i].num_nodes_per_side[0] = 2;
       else if (elem_blk_parms[i].num_nodes_per_elem == 4)
-        elem_blk_parms[i].num_nodes_per_side = 4;
+        elem_blk_parms[i].num_nodes_per_side[0] = 4;
       else
-        elem_blk_parms[i].num_nodes_per_side = 8;
+        elem_blk_parms[i].num_nodes_per_side[0] = 8;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"HEX",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = HEX;
+      elem_blk_parms[i].elem_type_val = EX_EL_HEX;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 8)
-        elem_blk_parms[i].num_nodes_per_side = 4;
+        elem_blk_parms[i].num_nodes_per_side[0] = 4;
       else if (elem_blk_parms[i].num_nodes_per_elem == 9)
-        elem_blk_parms[i].num_nodes_per_side = 4;
+        elem_blk_parms[i].num_nodes_per_side[0] = 4;
       else if (elem_blk_parms[i].num_nodes_per_elem == 12) /* HEXSHELL */
-        elem_blk_parms[i].num_nodes_per_side = 4;
+        elem_blk_parms[i].num_nodes_per_side[0] = 4;
       else if (elem_blk_parms[i].num_nodes_per_elem == 27)
-        elem_blk_parms[i].num_nodes_per_side = 9;
+        elem_blk_parms[i].num_nodes_per_side[0] = 9;
       else
-        elem_blk_parms[i].num_nodes_per_side = 8;
+        elem_blk_parms[i].num_nodes_per_side[0] = 8;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"TETRA",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = TETRA;
+      elem_blk_parms[i].elem_type_val = EX_EL_TETRA;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 4)
-        elem_blk_parms[i].num_nodes_per_side = 3;
+        elem_blk_parms[i].num_nodes_per_side[0] = 3;
       else if (elem_blk_parms[i].num_nodes_per_elem == 8)
-        elem_blk_parms[i].num_nodes_per_side = 4;
+        elem_blk_parms[i].num_nodes_per_side[0] = 4;
       else
-        elem_blk_parms[i].num_nodes_per_side = 6;
+        elem_blk_parms[i].num_nodes_per_side[0] = 6;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"WEDGE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = WEDGE;
+      elem_blk_parms[i].elem_type_val = EX_EL_WEDGE;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 6)
-        elem_blk_parms[i].num_nodes_per_side = 4;
+        elem_blk_parms[i].num_nodes_per_side[0] = 4;
       else
-        elem_blk_parms[i].num_nodes_per_side = 8;
+        elem_blk_parms[i].num_nodes_per_side[0] = 8;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"PYRAMID",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = PYRAMID;
+      elem_blk_parms[i].elem_type_val = EX_EL_PYRAMID;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 5)
-        elem_blk_parms[i].num_nodes_per_side = 4;
+        elem_blk_parms[i].num_nodes_per_side[0] = 4;
       else
-        elem_blk_parms[i].num_nodes_per_side = 8;
+        elem_blk_parms[i].num_nodes_per_side[0] = 8;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"BEAM",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = BEAM;
+      elem_blk_parms[i].elem_type_val = EX_EL_BEAM;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 2)
-        elem_blk_parms[i].num_nodes_per_side = 2;
+        elem_blk_parms[i].num_nodes_per_side[0] = 2;
       else 
-        elem_blk_parms[i].num_nodes_per_side = 3;
+        elem_blk_parms[i].num_nodes_per_side[0] = 3;
     }
     else if ( (strncmp(elem_blk_parms[i].elem_type,"TRUSS",3) == 0) ||
               (strncmp(elem_blk_parms[i].elem_type,"BAR",3) == 0)  ||
               (strncmp(elem_blk_parms[i].elem_type,"EDGE",3) == 0))
     {
-      elem_blk_parms[i].elem_type_val = TRUSS;
+      elem_blk_parms[i].elem_type_val = EX_EL_TRUSS;
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 2)
-        elem_blk_parms[i].num_nodes_per_side = 2;
+        elem_blk_parms[i].num_nodes_per_side[0] = 2;
       else 
-        elem_blk_parms[i].num_nodes_per_side = 3;
+        elem_blk_parms[i].num_nodes_per_side[0] = 3;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"NULL",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = '\0';
-      elem_blk_parms[i].num_nodes_per_side = 0;
+      elem_blk_parms[i].elem_type_val = EX_EL_NULL_ELEMENT;
+      elem_blk_parms[i].num_nodes_per_side[0] = 0;
       elem_blk_parms[i].num_elem_in_blk = 0;
     }
     else
     { /* unsupported element type; no problem if no sides specified for
          this element block */
-      elem_blk_parms[i].elem_type_val = UNK;
-      elem_blk_parms[i].num_nodes_per_side = 0;
+      elem_blk_parms[i].elem_type_val = EX_EL_UNK;
+      elem_blk_parms[i].num_nodes_per_side[0] = 0;
     }
 
     elem_ctr += elem_blk_parms[i].num_elem_in_blk;
@@ -434,7 +425,7 @@ int ex_get_side_set_node_list_len(int exoid,
   {
     for (j=0; j<num_elem_blks; j++)
     {
-      if (elem_blk_parms[j].elem_type_val != '\0')
+      if (elem_blk_parms[j].elem_type_val != EX_EL_NULL_ELEMENT)
         if (side_set_elem_list[i] <= elem_blk_parms[j].elem_ctr)
           break; /* stop because we found the parameters for this element */
     }
@@ -456,7 +447,7 @@ int ex_get_side_set_node_list_len(int exoid,
     /* Update *side_set_node_list_len (which points to next node in chain */
 
     /* WEDGEs with 3 node sides (side 4 or 5) are special cases */
-    if (elem_blk_parms[j].elem_type_val == WEDGE &&
+    if (elem_blk_parms[j].elem_type_val == EX_EL_WEDGE &&
         (side_set_side_list[i] == 4 || side_set_side_list[i] == 5))
     {
       if (elem_blk_parms[j].num_nodes_per_elem == 6)
@@ -465,7 +456,7 @@ int ex_get_side_set_node_list_len(int exoid,
         *side_set_node_list_len += 6;  /* 6 node side */
     }
     /* PYRAMIDSs with 3 node sides (sides 1,2,3,4) are also special */
-    else if (elem_blk_parms[j].elem_type_val == PYRAMID &&
+    else if (elem_blk_parms[j].elem_type_val == EX_EL_PYRAMID &&
              (side_set_side_list[i] < 5))
     {
       if (elem_blk_parms[j].num_nodes_per_elem == 5)
@@ -474,7 +465,7 @@ int ex_get_side_set_node_list_len(int exoid,
         *side_set_node_list_len += 6;  /* 6 node side */
     }
     /* side numbers 3,4,5,6 for SHELLs are also special */
-    else if (elem_blk_parms[j].elem_type_val == SHELL &&
+    else if (elem_blk_parms[j].elem_type_val == EX_EL_SHELL &&
         (side_set_side_list[i] > 2 ))
     {
       if (elem_blk_parms[j].num_nodes_per_elem == 4)
@@ -483,7 +474,7 @@ int ex_get_side_set_node_list_len(int exoid,
         *side_set_node_list_len += 3;  /* 3 node side */
     }
     /* sides 3, 4, and 5 of 3d TRIs are special cases */
-    else if (elem_blk_parms[j].elem_type_val == TRIANGLE &&
+    else if (elem_blk_parms[j].elem_type_val == EX_EL_TRIANGLE &&
              ndim == 3 &&
              side_set_side_list[i] > 2 )
     {
@@ -492,7 +483,7 @@ int ex_get_side_set_node_list_len(int exoid,
       else  /* 6-node TRI */
         *side_set_node_list_len += 3;  /* 3 node side */
     }
-    else if (elem_blk_parms[j].elem_type_val == UNK)
+    else if (elem_blk_parms[j].elem_type_val == EX_EL_UNK)
     {
       exerrval = EX_BADPARAM;
       sprintf(errmsg,
@@ -507,7 +498,7 @@ int ex_get_side_set_node_list_len(int exoid,
       return (EX_FATAL);
     }
     else /* all other element types */
-      *side_set_node_list_len += elem_blk_parms[j].num_nodes_per_side;
+      *side_set_node_list_len += elem_blk_parms[j].num_nodes_per_side[0];
   }
 
   /* All done: release element block ids array,
