@@ -46,7 +46,7 @@
 *                                       side or face
 * revision history - 
 *
-*  $Id: exgssc.c,v 1.7 2009-01-16 14:32:01 utkarsh Exp $
+*  $Id: exgssc.c,v 1.8 2010-03-01 19:26:42 ndfabia Exp $
 *****************************************************************************/
 
 #include <ctype.h>
@@ -68,7 +68,8 @@ int ex_get_side_set_node_count(int exoid,
                                int side_set_id,
                                int *side_set_node_cnt_list)
 {
-  int ii, i, j, m; 
+  size_t m;
+  int ii, i, j; 
   int  num_side_sets, num_elem_blks, num_df, ndim;
   int tot_num_elem = 0, tot_num_ss_elem = 0, side, elem;
   int *elem_blk_ids;
@@ -283,26 +284,26 @@ int ex_get_side_set_node_count(int exoid,
     elem_blk_parms[i].num_nodes_per_elem = num_nodes_per_elem;
     elem_blk_parms[i].num_attr = num_attr;
 
-    for (m=0; m < (int)strlen(elem_type); m++) {
+    for (m=0; m < strlen(elem_type); m++) {
       elem_blk_parms[i].elem_type[m] = toupper(elem_type[m]);
     }
     elem_blk_parms[i].elem_type[m] = '\0';
 
     if (strncmp(elem_blk_parms[i].elem_type,"CIRCLE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = CIRCLE;
+      elem_blk_parms[i].elem_type_val = EX_EL_CIRCLE;
       elem_blk_parms[i].num_sides = 1;
       elem_blk_parms[i].num_nodes_per_side[0] = 1;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"SPHERE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = SPHERE;
+      elem_blk_parms[i].elem_type_val = EX_EL_SPHERE;
       elem_blk_parms[i].num_sides = 1;
         elem_blk_parms[i].num_nodes_per_side[0] = 1;
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"QUAD",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = QUAD;
+      elem_blk_parms[i].elem_type_val = EX_EL_QUAD;
       elem_blk_parms[i].num_sides = 4;
       if (elem_blk_parms[i].num_nodes_per_elem == 4) {
         elem_blk_parms[i].num_nodes_per_side[0] = 2;
@@ -326,7 +327,7 @@ int ex_get_side_set_node_count(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"TRIANGLE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = TRIANGLE;
+      elem_blk_parms[i].elem_type_val = EX_EL_TRIANGLE;
       if (ndim == 2) { /* 2d TRIs */
         elem_blk_parms[i].num_sides = 3;
         if (elem_blk_parms[i].num_nodes_per_elem == 3) {
@@ -359,7 +360,7 @@ int ex_get_side_set_node_count(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"SHELL",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = SHELL;
+      elem_blk_parms[i].elem_type_val = EX_EL_SHELL;
 
       if (elem_blk_parms[i].num_nodes_per_elem == 2) {/* KLUDGE for 2D Shells*/
         elem_blk_parms[i].num_sides = 2; 
@@ -390,7 +391,7 @@ int ex_get_side_set_node_count(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"HEX",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = HEX;
+      elem_blk_parms[i].elem_type_val = EX_EL_HEX;
       elem_blk_parms[i].num_sides = 6;  
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 8) {  /* 8-node bricks */
@@ -434,7 +435,7 @@ int ex_get_side_set_node_count(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"TETRA",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = TETRA;
+      elem_blk_parms[i].elem_type_val = EX_EL_TETRA;
       elem_blk_parms[i].num_sides = 4;  
       /* determine side set node stride */
       if (elem_blk_parms[i].num_nodes_per_elem == 4) {
@@ -458,7 +459,7 @@ int ex_get_side_set_node_count(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"WEDGE",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = WEDGE;
+      elem_blk_parms[i].elem_type_val = EX_EL_WEDGE;
       elem_blk_parms[i].num_sides = 5;  
       if (elem_blk_parms[i].num_nodes_per_elem == 6) {
         elem_blk_parms[i].num_nodes_per_side[0] = 4;
@@ -478,7 +479,7 @@ int ex_get_side_set_node_count(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"PYRAMID",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = PYRAMID;
+      elem_blk_parms[i].elem_type_val = EX_EL_PYRAMID;
       elem_blk_parms[i].num_sides = 5;  
       if (elem_blk_parms[i].num_nodes_per_elem == 5) {
         elem_blk_parms[i].num_nodes_per_side[0] = 3;
@@ -498,7 +499,7 @@ int ex_get_side_set_node_count(int exoid,
     }
     else if (strncmp(elem_blk_parms[i].elem_type,"BEAM",3) == 0)
     {
-      elem_blk_parms[i].elem_type_val = BEAM;
+      elem_blk_parms[i].elem_type_val = EX_EL_BEAM;
       elem_blk_parms[i].num_sides = 2;  
 
       if (elem_blk_parms[i].num_nodes_per_elem == 2) {
@@ -515,7 +516,7 @@ int ex_get_side_set_node_count(int exoid,
               (strncmp(elem_blk_parms[i].elem_type,"BAR",3) == 0) ||
               (strncmp(elem_blk_parms[i].elem_type,"EDGE",3) == 0) )
     {
-      elem_blk_parms[i].elem_type_val = TRUSS;
+      elem_blk_parms[i].elem_type_val = EX_EL_TRUSS;
       elem_blk_parms[i].num_sides = 2;  
 
       if (elem_blk_parms[i].num_nodes_per_elem == 2) {
@@ -530,14 +531,14 @@ int ex_get_side_set_node_count(int exoid,
     }
     /* Used for an empty block in a parallel decomposition */
     else if (strncmp(elem_blk_parms[i].elem_type,"NULL",3) == 0) {
-      elem_blk_parms[i].elem_type_val = NULL_ELEMENT;
+      elem_blk_parms[i].elem_type_val = EX_EL_NULL_ELEMENT;
       elem_blk_parms[i].num_sides = 0;  
       elem_blk_parms[i].num_nodes_per_side[0] = 0;
       elem_blk_parms[i].num_elem_in_blk = 0;
     } else {
       /* unsupported element type; no problem if no sides specified for
          this element block */
-      elem_blk_parms[i].elem_type_val = UNK;
+      elem_blk_parms[i].elem_type_val = EX_EL_UNK;
       elem_blk_parms[i].num_sides = 0;  
       elem_blk_parms[i].num_nodes_per_side[0] = 0;
     }
