@@ -47,7 +47,7 @@
 *
 * revision history - 
 *
-*  $Id: expcor.c,v 1.7 2009-01-19 18:46:31 utkarsh Exp $
+*  $Id: expcor.c,v 1.8 2010-03-01 19:26:44 ndfabia Exp $
 *
 *****************************************************************************/
 
@@ -73,7 +73,7 @@ int ex_put_coord (int   exoid,
   int coordidx, coordidy, coordidz;
 
   int numnoddim, ndimdim;
-  size_t i, num_nod, num_dim, start[2], count[2];
+  size_t num_nod, num_dim, start[2], count[2], i;
   char errmsg[MAX_ERR_LENGTH];
 
   exerrval = 0; /* clear error code */
@@ -89,8 +89,8 @@ int ex_put_coord (int   exoid,
   if ((status = nc_inq_dimlen(exoid, numnoddim, &num_nod)) != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: inquire failed to return number of nodes in file id %d",
-	    exoid);
+            "Error: inquire failed to return number of nodes in file id %d",
+            exoid);
     ex_err("ex_put_coord",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -98,8 +98,8 @@ int ex_put_coord (int   exoid,
   if ((status = nc_inq_dimid(exoid, DIM_NUM_DIM, &ndimdim)) != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to locate number of dimensions in file id %d",
-	    exoid);
+            "Error: failed to locate number of dimensions in file id %d",
+            exoid);
     ex_err("ex_put_coord",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -107,8 +107,8 @@ int ex_put_coord (int   exoid,
   if ((status = nc_inq_dimlen(exoid, ndimdim, &num_dim)) != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to get number of dimensions in file id %d",
-	    exoid);
+            "Error: failed to get number of dimensions in file id %d",
+            exoid);
     ex_err("ex_put_coord",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -132,65 +132,65 @@ int ex_put_coord (int   exoid,
       count[1] = num_nod;
 
       if (i == 0 && x_coor != NULL) {
-	which = "X";
-	if (ex_comp_ws(exoid) == 4) {
-	  status = nc_put_vara_float(exoid, coordid, start, count, x_coor);
-	} else {
-	  status = nc_put_vara_double(exoid, coordid, start, count, x_coor);
-	}
-      }	  
+        which = "X";
+        if (ex_comp_ws(exoid) == 4) {
+          status = nc_put_vara_float(exoid, coordid, start, count, x_coor);
+        } else {
+          status = nc_put_vara_double(exoid, coordid, start, count, x_coor);
+        }
+      }   
       else if (i == 1 && y_coor != NULL) {
-	which = "Y";
-	if (ex_comp_ws(exoid) == 4) {
-	  status = nc_put_vara_float(exoid, coordid, start, count, y_coor);
-	} else {
-	  status = nc_put_vara_double(exoid, coordid, start, count, y_coor);
-	}
+        which = "Y";
+        if (ex_comp_ws(exoid) == 4) {
+          status = nc_put_vara_float(exoid, coordid, start, count, y_coor);
+        } else {
+          status = nc_put_vara_double(exoid, coordid, start, count, y_coor);
+        }
       }
       else if (i == 2 && z_coor != NULL) {
-	which = "Z";
-	if (ex_comp_ws(exoid) == 4) {
-	  status = nc_put_vara_float(exoid, coordid, start, count, z_coor);
-	} else {
-	  status = nc_put_vara_double(exoid, coordid, start, count, z_coor);
-	}
+        which = "Z";
+        if (ex_comp_ws(exoid) == 4) {
+          status = nc_put_vara_float(exoid, coordid, start, count, z_coor);
+        } else {
+          status = nc_put_vara_double(exoid, coordid, start, count, z_coor);
+        }
       }
-	  
+          
       if (status != NC_NOERR) {
-	exerrval = status;
-	sprintf(errmsg,
-		"Error: failed to put %s coord array in file id %d", which, exoid);
-	ex_err("ex_put_coord",errmsg,exerrval);
-	return (EX_FATAL);
+        exerrval = status;
+        sprintf(errmsg,
+                "Error: failed to put %s coord array in file id %d", which, exoid);
+        ex_err("ex_put_coord",errmsg,exerrval);
+        return (EX_FATAL);
       }
     }
   } else {
     if ((status = nc_inq_varid(exoid, VAR_COORD_X, &coordidx)) != NC_NOERR) {
       exerrval = status;
       sprintf(errmsg,
-	      "Error: failed to locate x nodal coordinates in file id %d", exoid);
+              "Error: failed to locate x nodal coordinates in file id %d", exoid);
       ex_err("ex_put_coord",errmsg,exerrval);
       return (EX_FATAL);
     }
 
     if (num_dim > 1) {
       if ((status = nc_inq_varid(exoid, VAR_COORD_Y, &coordidy)) != NC_NOERR) {
-	exerrval = status;
-	sprintf(errmsg,
-		"Error: failed to locate y nodal coordinates in file id %d", exoid);
-	ex_err("ex_put_coord",errmsg,exerrval);
-	return (EX_FATAL);
+        exerrval = status;
+        sprintf(errmsg,
+                "Error: failed to locate y nodal coordinates in file id %d", exoid);
+        ex_err("ex_put_coord",errmsg,exerrval);
+        return (EX_FATAL);
       }
     } else {
       coordidy = 0;
     }
     if (num_dim > 2) {
       if ((status = nc_inq_varid(exoid, VAR_COORD_Z, &coordidz)) != NC_NOERR) {
-	exerrval = status;
-	sprintf(errmsg,
-		"Error: failed to locate z nodal coordinates in file id %d", exoid);
-	ex_err("ex_put_coord",errmsg,exerrval);
-	return (EX_FATAL);
+        exerrval = status;
+        sprintf(errmsg,
+                "Error: failed to locate z nodal coordinates in file id %d", exoid);
+        ex_err("ex_put_coord",errmsg,exerrval);
+        return (EX_FATAL);
       }
     } else {
       coordidz = 0;
@@ -198,37 +198,37 @@ int ex_put_coord (int   exoid,
 
     /* write out the coordinates  */
     for (i=0; i<num_dim; i++) {
-      const void *coor = NULL;
-      char *which = NULL;
+      const void *coor;
+      char *which;
        
       if (i == 0) {
-	coor = x_coor;
-	which = "X";
-	coordid = coordidx;
+        coor = x_coor;
+        which = "X";
+        coordid = coordidx;
       } else if (i == 1) {
-	coor = y_coor;
-	which = "Y";
-	coordid = coordidy;
+        coor = y_coor;
+        which = "Y";
+        coordid = coordidy;
       } else if (i == 2) {
-	coor = z_coor;
-	which = "Z";
-	coordid = coordidz;
+        coor = z_coor;
+        which = "Z";
+        coordid = coordidz;
       }
 
       if (coor != NULL && coordid != 0) {
-	if (ex_comp_ws(exoid) == 4) {
-	  status = nc_put_var_float(exoid, coordid, coor);
-	} else {
-	  status = nc_put_var_double(exoid, coordid, coor);
-	}
+        if (ex_comp_ws(exoid) == 4) {
+          status = nc_put_var_float(exoid, coordid, coor);
+        } else {
+          status = nc_put_var_double(exoid, coordid, coor);
+        }
 
-	if (status != NC_NOERR) {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: failed to put %s coord array in file id %d", which, exoid);
-	  ex_err("ex_put_coord",errmsg,exerrval);
-	  return (EX_FATAL);
-	}
+        if (status != NC_NOERR) {
+          exerrval = status;
+          sprintf(errmsg,
+                  "Error: failed to put %s coord array in file id %d", which, exoid);
+          ex_err("ex_put_coord",errmsg,exerrval);
+          return (EX_FATAL);
+        }
       }
     }
   }
