@@ -26,7 +26,7 @@
 
 //---------------------------------------------------------------------------
 
-vtkCxxRevisionMacro(vtkImageOrthoPlanes, "$Revision: 1.5 $"); 
+vtkCxxRevisionMacro(vtkImageOrthoPlanes, "$Revision: 1.6 $"); 
 vtkStandardNewMacro(vtkImageOrthoPlanes);
 
 //---------------------------------------------------------------------------
@@ -485,9 +485,9 @@ void vtkImageOrthoPlanes::HandlePlaneScale(
   double scale[3];
   double relativeScale[3];
 
-  relativeScale[0] = 1.0;
-  relativeScale[1] = 1.0;
-  relativeScale[2] = 1.0;
+  relativeScale[0] = scale[0] = 1.0;
+  relativeScale[1] = scale[1] = 1.0;
+  relativeScale[2] = scale[2] = 1.0;
 
   switch (indexOfModifiedPlane)
     {
