@@ -51,17 +51,23 @@
 // With shift key modifier: uniform plane scaling is enabled.  Moving the mouse
 // up enlarges the plane while downward movement shrinks it.
 //
-// Window-level is achieved by using the right mouse button.
+// Window-level is achieved by using the right mouse button.  Window-level
+// values can be reset by shift + 'r' or control + 'r' while regular reset
+// camera is maintained with 'r' or 'R'.
 // The left mouse button can be used to query the underlying image data
 // with a snap-to cross-hair cursor.  Currently, the nearest point in the input
 // image data to the mouse cursor generates the cross-hairs.  With oblique
 // slicing, this behaviour may appear unsatisfactory. Text display of
 // window-level and image coordinates/data values are provided by a text
 // actor/mapper pair.
+//
 // Events that occur outside of the widget (i.e., no part of the widget is
 // picked) are propagated to any other registered obsevers (such as the
 // interaction style). Turn off the widget by pressing the "i" key again
-// (or invoke the Off() method).
+// (or invoke the Off() method). To support interactive manipulation of
+// objects, this class invokes the events StartInteractionEvent,
+// InteractionEvent, and EndInteractionEvent as well as StartWindowLevelEvent,
+// WindowLevelEvent, EndWindowLevelEvent and ResetWindowLevelEvent.
 //
 // The vtkImagePlaneWidget has several methods that can be used in
 // conjunction with other VTK objects. The GetPolyData() method can be used
@@ -99,7 +105,7 @@
 #include "vtkPolyDataSourceWidget.h"
 
 class vtkActor;
-class vtkCellPicker;
+class vtkAbstractPropPicker;
 class vtkDataSetMapper;
 class vtkImageData;
 class vtkImageMapToColors;
@@ -232,7 +238,7 @@ public:
   // Specify whether to interpolate the texture or not. When off, the
   // reslice interpolation is nearest neighbour regardless of how the
   // interpolation is set through the API. Set before setting the
-  // vtkImageData imput. Default is On.
+  // vtkImageData input. Default is On.
   vtkSetMacro(TextureInterpolate,int);
   vtkGetMacro(TextureInterpolate,int);
   vtkBooleanMacro(TextureInterpolate,int);
@@ -250,19 +256,19 @@ public:
   // polygons, where res is the resolution of the plane. These point values
   // are guaranteed to be up-to-date when either the InteractionEvent or
   // EndInteraction events are invoked. The user provides the vtkPolyData and
-  // the points and polyplane are added to it.
+  // the points and polygons are added to it.
   void GetPolyData(vtkPolyData *pd);
 
   // Description:
   // Satisfies superclass API.  This returns a pointer to the underlying
-  // PolyData.  Make changes to this before calling the initial PlaceWidget()
+  // vtkPolyData.  Make changes to this before calling the initial PlaceWidget()
   // to have the initial placement follow suit.  Or, make changes after the
   // widget has been initialised and call UpdatePlacement() to realise.
   vtkPolyDataAlgorithm* GetPolyDataAlgorithm();
 
   // Description:
   // Satisfies superclass API.  This will change the state of the widget to
-  // match changes that have been made to the underlying PolyDataSource
+  // match changes that have been made to the underlying vtkPolyDataSource
   void UpdatePlacement(void);
 
   // Description:
@@ -273,7 +279,7 @@ public:
   // Description:
   // Convenience method to get the vtkImageMapToColors filter used by this
   // widget.  The user can properly render other transparent actors in a
-  // scene by calling the filter's SetOuputFormatToRGB and 
+  // scene by calling the filter's SetOutputFormatToRGB and 
   // PassAlphaToOutputOff.
   vtkGetObjectMacro(ColorMap, vtkImageMapToColors);
   virtual void SetColorMap(vtkImageMapToColors *);
@@ -303,7 +309,7 @@ public:
   // a set of three orthogonal planes can share the same picker so that
   // picking is performed correctly.  The default internal picker can be
   // re-set/allocated by setting to 0 (NULL).
-  void SetPicker(vtkCellPicker*);
+  void SetPicker(vtkAbstractPropPicker*);
 
   // Description:
   // Set/Get the internal lookuptable (lut) to one defined by the user, or,
@@ -315,8 +321,8 @@ public:
   vtkGetObjectMacro(LookupTable,vtkLookupTable);
 
   // Description:
-  // Enable/disable text display of window-level, image coords and values in a
-  // render window.
+  // Enable/disable text display of window-level, image coordinates and
+  // scalar values in a render window.
   vtkSetMacro(DisplayText,int);
   vtkGetMacro(DisplayText,int);
   vtkBooleanMacro(DisplayText,int);
@@ -331,6 +337,14 @@ public:
   virtual void SetMarginProperty(vtkProperty*);
   vtkGetObjectMacro(MarginProperty,vtkProperty);
 
+  // Description:
+  // Set the size of the margins based on a percentage of the
+  // plane's width and height, limited between 0 and 50%.
+  vtkSetClampMacro(MarginSizeX,double, 0.0, 0.5);
+  vtkGetMacro(MarginSizeX, double);
+  vtkSetClampMacro(MarginSizeY,double, 0.0, 0.5);
+  vtkGetMacro(MarginSizeY, double);
+
   // Description:
   // Set/Get the text property for the image data and window-level annotation.
   void SetTextProperty(vtkTextProperty* tprop);
@@ -342,10 +356,14 @@ public:
   vtkGetObjectMacro(TexturePlaneProperty,vtkProperty);
 
   // Description:
-  // Set/Get the current window and level values.  Set should
-  // only be called after SetInput.
-  void SetWindowLevel(double window, double level);
+  // Set/Get the current window and level values.  SetWindowLevel should
+  // only be called after SetInput.  If a shared lookup table is being used,
+  // a callback is required to update the window level values without having
+  // to update the lookup table again.
+  void SetWindowLevel(double window, double level, int copy = 0);
   void GetWindowLevel(double wl[2]);
+  double GetWindow(){return this->CurrentWindow;}
+  double GetLevel(){return this->CurrentLevel;}
 
   // Description:
   // Get the image coordinate position and voxel value.  Currently only
@@ -368,13 +386,13 @@ public:
   // be used in conjunction with GetCursorDataStatus.  The value is
   // VTK_DOUBLE_MAX when the data is invalid.
   vtkGetMacro(CurrentImageValue,double);
-  
+
   // Description:
   // Choose between voxel centered or continuous cursor probing.  With voxel
   // centered probing, the cursor snaps to the nearest voxel and the reported
   // cursor coordinates are extent based.  With continuous probing, voxel data
   // is interpolated using vtkDataSetAttributes' InterpolatePoint method and
-  // the reported coordinates are 3D spacial continuous.  
+  // the reported coordinates are 3D spatial continuous.
   vtkSetMacro(UseContinuousCursor,int);
   vtkGetMacro(UseContinuousCursor,int);
   vtkBooleanMacro(UseContinuousCursor,int);
@@ -390,38 +408,38 @@ public:
   //BTX
   enum
   {
-    CURSOR_ACTION       = 0,
-    SLICE_MOTION_ACTION = 1,
-    WINDOW_LEVEL_ACTION = 2
+    VTK_CURSOR_ACTION       = 0,
+    VTK_SLICE_MOTION_ACTION = 1,
+    VTK_WINDOW_LEVEL_ACTION = 2
   };
   //ETX
-  vtkSetClampMacro(LeftButtonAction,int, CURSOR_ACTION, WINDOW_LEVEL_ACTION);
+  vtkSetClampMacro(LeftButtonAction,int, VTK_CURSOR_ACTION, VTK_WINDOW_LEVEL_ACTION);
   vtkGetMacro(LeftButtonAction, int);
-  vtkSetClampMacro(MiddleButtonAction,int, CURSOR_ACTION, WINDOW_LEVEL_ACTION);
+  vtkSetClampMacro(MiddleButtonAction,int, VTK_CURSOR_ACTION, VTK_WINDOW_LEVEL_ACTION);
   vtkGetMacro(MiddleButtonAction, int);
-  vtkSetClampMacro(RightButtonAction,int, CURSOR_ACTION, WINDOW_LEVEL_ACTION);
+  vtkSetClampMacro(RightButtonAction,int, VTK_CURSOR_ACTION, VTK_WINDOW_LEVEL_ACTION);
   vtkGetMacro(RightButtonAction, int);
 
   // Description:
   // Set the auto-modifiers associated to buttons.
   // This allows users to bind some buttons to actions that are usually
   // triggered by a key modifier. For example, if you do not need cursoring,
-  // you can bind the left button action to SLICE_MOTION_ACTION (see above) 
-  // and the left button auto modifier to CONTROL_MODIFIER: you end up with
+  // you can bind the left button action to VTK_SLICE_MOTION_ACTION (see above) 
+  // and the left button auto modifier to VTK_CONTROL_MODIFIER: you end up with
   // the left button controling panning without pressing a key.
   //BTX
   enum
   {
-    NO_MODIFIER         = 0,
-    SHIFT_MODIFIER      = 1,
-    CONTROL_MODIFIER    = 2
+    VTK_NO_MODIFIER         = 0,
+    VTK_SHIFT_MODIFIER      = 1,
+    VTK_CONTROL_MODIFIER    = 2
   };
   //ETX
-  vtkSetClampMacro(LeftButtonAutoModifier,int, NO_MODIFIER, CONTROL_MODIFIER);
+  vtkSetClampMacro(LeftButtonAutoModifier,int, VTK_NO_MODIFIER, VTK_CONTROL_MODIFIER);
   vtkGetMacro(LeftButtonAutoModifier, int);
-  vtkSetClampMacro(MiddleButtonAutoModifier,int, NO_MODIFIER, CONTROL_MODIFIER);
+  vtkSetClampMacro(MiddleButtonAutoModifier,int, VTK_NO_MODIFIER, VTK_CONTROL_MODIFIER);
   vtkGetMacro(MiddleButtonAutoModifier, int);
-  vtkSetClampMacro(RightButtonAutoModifier,int, NO_MODIFIER, CONTROL_MODIFIER);
+  vtkSetClampMacro(RightButtonAutoModifier,int, VTK_NO_MODIFIER, VTK_CONTROL_MODIFIER);
   vtkGetMacro(RightButtonAutoModifier, int);
 
 protected:
@@ -441,10 +459,10 @@ protected:
   //BTX
   enum
   {
-    NO_BUTTON     = 0,
-    LEFT_BUTTON   = 1,
-    MIDDLE_BUTTON = 2,
-    RIGHT_BUTTON  = 3
+    VTK_NO_BUTTON     = 0,
+    VTK_LEFT_BUTTON   = 1,
+    VTK_MIDDLE_BUTTON = 2,
+    VTK_RIGHT_BUTTON  = 3
   };
   //ETX
   int LastButtonPressed;
@@ -484,6 +502,7 @@ protected:
   virtual void OnMiddleButtonUp();
   virtual void OnRightButtonDown();
   virtual void OnRightButtonUp();
+  virtual void OnChar();
 
   virtual void StartCursor();
   virtual void StopCursor();
@@ -493,17 +512,21 @@ protected:
   virtual void StopWindowLevel();
 
   // controlling ivars
-  int   Interaction; // Is the widget responsive to mouse events  
-  int   PlaneOrientation;
-  int   RestrictPlaneToVolume;
+  int    Interaction; // Is the widget responsive to mouse events
+  int    PlaneOrientation;
+  int    RestrictPlaneToVolume;
   double OriginalWindow;
   double OriginalLevel;
   double CurrentWindow;
   double CurrentLevel;
-  int   ResliceInterpolate;
-  int   TextureInterpolate;
-  int   UserControlledLookupTable;
-  int   DisplayText;
+  double InitialWindow;
+  double InitialLevel;
+  int    StartWindowLevelPositionX;
+  int    StartWindowLevelPositionY;
+  int    ResliceInterpolate;
+  int    TextureInterpolate;
+  int    UserControlledLookupTable;
+  int    DisplayText;
 
   // The geometric represenation of the plane and it's outline
   vtkPlaneSource    *PlaneSource;
@@ -516,7 +539,10 @@ protected:
   void BuildRepresentation();
 
   // Do the picking
-  vtkCellPicker *PlanePicker;
+  vtkAbstractPropPicker *PlanePicker;
+
+  // for negative window values.
+  void InvertTable();
 
   // Methods to manipulate the plane
   void WindowLevel(int X, int Y);
@@ -582,6 +608,8 @@ protected:
   void               GenerateMargins();
   void               UpdateMargins();
   void               ActivateMargins(int);
+  double             MarginSizeX;
+  double             MarginSizeY;
 
 private:
   vtkImagePlaneWidget(const vtkImagePlaneWidget&);  //Not implemented
