@@ -28,12 +28,14 @@
     int   HintSize;
     int   ArgTypes[MAX_ARGS];
     int   ArgCounts[MAX_ARGS];
+    int   ArgExternals[MAX_ARGS];
     char *ArgClasses[MAX_ARGS];
     int   ReturnType;
     char *ReturnClass;
     char *Comment;
     char *Signature;  
     int   IsLegacy;
+    int   ReturnExternal;
   } FunctionInfo;
   
   typedef struct _FileInfo
